From: Chris Koeritz
+
+DEPRECATED
@@ -295,7 +297,7 @@
-
Important Variables
The clam root directory is pointed to by an internal variable called
- "CLAM_DIR",
+ "CLAM_SCRIPTS",
defined in $/variables.def. This variable is used by the clam
system
to find extra files that might be needed by derived makefile
support.
It is important to change this to the appropriate value when you are
- using the system in a different location. The CLAM_DIR variable
+ using the system in a different location. The CLAM_SCRIPTS variable
can either
be directly edited in $/variables.def, or it can be overridden in the
environment
@@ -644,7 +646,7 @@
are
generated. All files generated by compilation are stored in the
repository
- directory (by default, either "~/hoople" in Linux or "l:\" in
+ directory (by default, either "~/feisty_meow" in Linux or "l:\" in
win32). There are three TYPEs supported so far:
SOURCE is a list of files that
are to be
compiled
@@ -867,7 +878,7 @@
MIDL is also a provided macro; it executes the
Microsoft
IDL compiler.
- $(HIDESH) $(CLAM_DIR)/postconditions.sh
+ $(HIDESH) $(CLAM_SCRIPTS)/postconditions.sh
This runs a shell script that handles the end
portion of a
@@ -983,11 +994,11 @@
but this will trap errors it sees and play the build error
CLAM_ERROR_SOUND.
- CLAM_BINARY_DIR
+ CLAM_BINARIES
This is a folder where the helper
binaries for the CLAM makefile system are located.
- CLAM_DIR
+ CLAM_SCRIPTS
This variable points at the location
where the definitions and helper scripts are located. The
default is
@@ -1132,7 +1143,7 @@
repository
is also where source code and final products of compilation reside,
unless
- the default is over-ridden (see TARGETS_DIR).
+ the default is over-ridden (see TARGETS_STORE).
SH & SHELL
These variables both point at a
@@ -1171,7 +1182,7 @@
Instead,
a generated variable called ACTUAL_TARGETS is used.
- TARGETS_DIR
+ TARGETS_STORE
This folder is where all generated
files are
to
@@ -1712,12 +1723,14 @@
for C++ header files (files ending in ?.h?).
HOOPLE_HEADERS
+DEPRECATED
The two standard places to look for
headers
(the repository and the third party directory) are listed in this
variable.
HOOPLE_LIBRARIES
+DEPRECATED
This is where our libraries are
located. It is usually a subdirectory called "lib" under the
repository
@@ -2285,7 +2298,7 @@
The most frequent cause of this
problem is a
directory
- not being on your path. The compilation tools bin (~/hoople/bin)
+ not being on your path. The compilation tools bin (CLAM_BINARIES)
directory must be in
the PATH variable.
diff --git a/doc/feisty_meow_dox.config b/doc/feisty_meow_dox.config
index 6ebbf79e..4c0f610d 100644
--- a/doc/feisty_meow_dox.config
+++ b/doc/feisty_meow_dox.config
@@ -448,7 +448,7 @@ INPUT = \
$(FEISTY_MEOW_APEX)/octopi \
$(FEISTY_MEOW_APEX)/graphiq \
$(FEISTY_MEOW_APEX)/kona/src \
- $(PRODUCTION_DIR)/setup_src
+ $(PRODUCTION_STORE)/setup_src
# If the value of the INPUT tag contains directories, you can use the
# FILE_PATTERNS tag to specify one or more wildcard pattern (like *.cpp
@@ -627,7 +627,7 @@ GENERATE_HTML = YES
# If a relative path is entered the value of OUTPUT_DIRECTORY will be
# put in front of it. If left blank `html' will be used as the default path.
-HTML_OUTPUT = $(PRODUCTION_DIR)/code_guide
+HTML_OUTPUT = $(PRODUCTION_STORE)/code_guide
# The HTML_FILE_EXTENSION tag can be used to specify the file extension for
# each generated HTML page (for example: .htm,.php,.asp). If it is left blank
diff --git a/nucleus/applications/bookmark_tools/js_marks_maker.cpp b/nucleus/applications/bookmark_tools/js_marks_maker.cpp
index a620e640..49578283 100644
--- a/nucleus/applications/bookmark_tools/js_marks_maker.cpp
+++ b/nucleus/applications/bookmark_tools/js_marks_maker.cpp
@@ -103,7 +103,7 @@ by finding the phrase $INSERT_LINKS_HERE in it and replacing that with html\n\
formatted link and categories from the input file. Another tag of $TODAYS_DATE\n\
will be replaced with the date when the output file is regenerated.\n\
The HOOPLE link format is documented here:\n\
- http://hoople.org/guides/link_database/format_manifesto.txt\n\
+ http://feistymeow.org/guides/link_database/format_manifesto.txt\n\
", program_name.basename().raw().s(), program_name.basename().raw().s());
program_wide_logger::get().log(to_show, ALWAYS_PRINT);
return 12;
diff --git a/nucleus/applications/bookmark_tools/link_parser.cpp b/nucleus/applications/bookmark_tools/link_parser.cpp
index 84467b5e..9e070abb 100644
--- a/nucleus/applications/bookmark_tools/link_parser.cpp
+++ b/nucleus/applications/bookmark_tools/link_parser.cpp
@@ -241,7 +241,7 @@ is basically a CSV file that defines the columns 1-4 for describing either\n\
link categories (which support hierarchies) or actual links (i.e., URLs of\n\
interest). The links are written to a CSV file in the standard HOOPLE link\n\
The HOOPLE link format is documented here:\n\
- http://hoople.org/guides/link_database/format_manifesto.txt\n\
+ http://feistymeow.org/guides/link_database/format_manifesto.txt\n\
", program_name.basename().raw().s(), program_name.basename().raw().s());
program_wide_logger::get().log(to_show, ALWAYS_PRINT);
return 12;
diff --git a/nucleus/applications/bookmark_tools/marks_checker.cpp b/nucleus/applications/bookmark_tools/marks_checker.cpp
index 1e2c6f07..ba8a2a82 100644
--- a/nucleus/applications/bookmark_tools/marks_checker.cpp
+++ b/nucleus/applications/bookmark_tools/marks_checker.cpp
@@ -209,7 +209,7 @@ The optional flag --threads with a parameter will set the maximum number of\n\
threads that will simultaneously check on links.\n\
The input file is expected to be in the HOOPLE link database format.\n\
The HOOPLE link format is documented here:\n\
- http://hoople.org/guides/link_database/format_manifesto.txt\n\
+ http://feistymeow.org/guides/link_database/format_manifesto.txt\n\
", program_name.basename().raw().s(), program_name.basename().raw().s());
program_wide_logger::get().log(to_show, ALWAYS_PRINT);
return 12;
diff --git a/nucleus/applications/bookmark_tools/marks_maker.cpp b/nucleus/applications/bookmark_tools/marks_maker.cpp
index 8e2cbef5..c7b63b67 100644
--- a/nucleus/applications/bookmark_tools/marks_maker.cpp
+++ b/nucleus/applications/bookmark_tools/marks_maker.cpp
@@ -130,7 +130,7 @@ Note that an optional -s flag can specify a value of \"human\" readable\n\
or \"mozilla\" bookmarks style to specify the style of the output file\n\
generated.\n\
The HOOPLE link format is documented here:\n\
- http://hoople.org/guides/link_database/format_manifesto.txt\n\
+ http://feistymeow.org/guides/link_database/format_manifesto.txt\n\
", program_name.basename().raw().s(), program_name.basename().raw().s());
program_wide_logger::get().log(to_show, ALWAYS_PRINT);
return 12;
diff --git a/nucleus/applications/bookmark_tools/marks_sorter.cpp b/nucleus/applications/bookmark_tools/marks_sorter.cpp
index b793d373..8201799b 100644
--- a/nucleus/applications/bookmark_tools/marks_sorter.cpp
+++ b/nucleus/applications/bookmark_tools/marks_sorter.cpp
@@ -82,7 +82,7 @@ is used to specify the input filename, which is expected to be in the HOOPLE\n\
link database format. The -o flag specifies the new bookmarks file to be\n\
created, which will also be in the HOOPLE link format.\n\
The HOOPLE link format is documented here:\n\
- http://hoople.org/guides/link_database/format_manifesto.txt\n\
+ http://feistymeow.org/guides/link_database/format_manifesto.txt\n\
", program_name.basename().raw().s(), program_name.basename().raw().s());
program_wide_logger::get().log(to_show, ALWAYS_PRINT);
return 12;
diff --git a/nucleus/applications/bundler/bundle_creator.cpp b/nucleus/applications/bundler/bundle_creator.cpp
index 533a45e2..17a2a8d0 100644
--- a/nucleus/applications/bundler/bundle_creator.cpp
+++ b/nucleus/applications/bundler/bundle_creator.cpp
@@ -748,7 +748,7 @@ astring bundle_creator::determine_stub_file_and_validate()
#ifdef __WIN32__
astring stub_filename("unpacker_stub.exe");
#endif
- astring repo_dir = "$RUNTIME_DIR";
+ astring repo_dir = "$RUNTIME_PATH";
astring stub_file = parser_bits::substitute_env_vars
(repo_dir + "/binaries/" + stub_filename, false);
if (!filename(stub_file).exists()) {
diff --git a/nucleus/library/tests_filesystem/test_directory_tree.cpp b/nucleus/library/tests_filesystem/test_directory_tree.cpp
index 4a5f588d..77b32a37 100644
--- a/nucleus/library/tests_filesystem/test_directory_tree.cpp
+++ b/nucleus/library/tests_filesystem/test_directory_tree.cpp
@@ -197,7 +197,7 @@ LOG(diffs.text_form());
LOG("reading tree to recreate");
directory_tree dir(path, pattern.s());
ASSERT_TRUE(dir.good(), "makedirs test directory reading");
- filename tmpdir(environment::get("GENERATED_DIR") + "/zz_balfazzaral");
+ filename tmpdir(environment::get("GENERATED_STORE") + "/zz_balfazzaral");
LOG(astring("will write to tmp in ") + tmpdir);
basis::outcome result = dir.make_directories(tmpdir.raw());
ASSERT_EQUAL(result.value(), common::OKAY, "makedirs should succeed");
diff --git a/nucleus/library/unit_test/unit_base.cpp b/nucleus/library/unit_test/unit_base.cpp
index 2eb67f19..08e7a896 100644
--- a/nucleus/library/unit_test/unit_base.cpp
+++ b/nucleus/library/unit_test/unit_base.cpp
@@ -299,7 +299,7 @@ int unit_base::final_report()
void unit_base::write_cppunit_xml()
{
auto_synchronizer synch(c_lock);
- astring logs_dir = environment::get("LOGS_DIR");
+ astring logs_dir = environment::get("FEISTY_MEOW_LOGS");
if (logs_dir == astring::empty_string()) logs_dir = "logs"; // uhhh.
astring outfile = logs_dir + "/"
+ filename(application_configuration::application_name()).basename().raw()
diff --git a/nucleus/makefile b/nucleus/makefile
index 4f931027..65b0bbd0 100644
--- a/nucleus/makefile
+++ b/nucleus/makefile
@@ -7,46 +7,46 @@ include variables.def
ifeq "$(FEISTY_MEOW_APEX)" ""
export FEISTY_MEOW_APEX := $(CURRENT_DIR)
endif
-#ifeq "$(PRODUCTION_DIR)" ""
-# export PRODUCTION_DIR = $(FEISTY_MEOW_APEX)/production
+#ifeq "$(PRODUCTION_STORE)" ""
+# export PRODUCTION_STORE = $(FEISTY_MEOW_APEX)/production
#endif
-ifeq "$(CLAM_DIR)" ""
- export CLAM_DIR = $(FEISTY_MEOW_SCRIPTS)/clam
+ifeq "$(CLAM_SCRIPTS)" ""
+ export CLAM_SCRIPTS = $(FEISTY_MEOW_SCRIPTS)/clam
endif
-include $(CLAM_DIR)/cpp/variables.def
+include $(CLAM_SCRIPTS)/cpp/variables.def
PROJECT = feisty_meow_nucleus
TYPE = hierarchy
FIRST_TARGETS += do_make
BUILD_AFTER = library applications tools
-include $(CLAM_DIR)/cpp/rules.def
+include $(CLAM_SCRIPTS)/cpp/rules.def
-do_make: start_make $(RUNTIME_DIR)/binaries/manifest.txt end_make
+do_make: start_make $(RUNTIME_PATH)/binaries/manifest.txt end_make
start_make: show_date.start
end_make: show_date.end
-$(RUNTIME_DIR)/binaries/manifest.txt: $(PARAMETER_FILE)
+$(RUNTIME_PATH)/binaries/manifest.txt: $(PARAMETER_FILE)
$(HIDESH) -c '\
if [ ! -d "$(EXECUTABLE_DIR)" ]; then mkdir -p "$(EXECUTABLE_DIR)"; fi; \
if [ $$? -ne 0 ]; then \
echo build failure while creating executable directory.; \
exit 1; \
fi; \
-cp -f "$(PRODUCTION_DIR)/paths.ini" "$(EXECUTABLE_DIR)"; \
+cp -f "$(PRODUCTION_STORE)/paths.ini" "$(EXECUTABLE_DIR)"; \
if [ $$? -ne 0 ]; then \
echo build failure while copying paths initialization file.; \
exit 1; \
fi; \
-bash $(BUILD_SCRIPTS_DIR)/wrapdoze.sh $(CLAM_BINARY_DIR)/value_tagger$(EXE_END) $(PRODUCTION_DIR)/codescan.ini; \
+bash $(BUILD_SCRIPTS_PATH)/wrapdoze.sh $(CLAM_BINARIES)/value_tagger$(EXE_END) $(PRODUCTION_STORE)/codescan.ini; \
if [ $$? -ne 0 ]; then \
echo build failure during value tagging.; \
exit 1; \
fi; \
-bash $(BUILD_SCRIPTS_DIR)/wrapdoze.sh $(CLAM_BINARY_DIR)/write_build_config$(EXE_END); \
+bash $(BUILD_SCRIPTS_PATH)/wrapdoze.sh $(CLAM_BINARIES)/write_build_config$(EXE_END); \
if [ $$? -ne 0 ]; then \
echo build failure while writing config.; \
exit 1; \
diff --git a/production/assign_bases/rebaser.sh b/production/assign_bases/rebaser.sh
index eaa8bfca..261911be 100644
--- a/production/assign_bases/rebaser.sh
+++ b/production/assign_bases/rebaser.sh
@@ -1,4 +1,4 @@
#!/bin/sh
-bash $PRODUCTION_DIR/assign_bases/whack_odd_dlls.sh
+bash $PRODUCTION_STORE/assign_bases/whack_odd_dlls.sh
"$VS80COMNTOOLS/Bin"/rebase.exe -b 0x68000000 -d $DYNAMIC_LIBRARY_DIR/*.dll
diff --git a/production/assign_bases/whack_odd_dlls.sh b/production/assign_bases/whack_odd_dlls.sh
index d9f23ddd..4d74f9b8 100644
--- a/production/assign_bases/whack_odd_dlls.sh
+++ b/production/assign_bases/whack_odd_dlls.sh
@@ -1,6 +1,6 @@
#!/bin/bash
-DA_DIR="$RUNTIME_DIR/binaries"
+DA_DIR="$RUNTIME_PATH/binaries"
rm -f $DA_DIR/AxInterop.*.dll \
$DA_DIR/DevAge*dll \
diff --git a/production/paths.ini b/production/paths.ini
index 8235e660..c9ee4edc 100644
--- a/production/paths.ini
+++ b/production/paths.ini
@@ -1,3 +1,3 @@
[Common]
-LogPath=$GENERATED_DIR/logs
+LogPath=$GENERATED_STORE/logs
diff --git a/production/setup_src/bundle_example/create_bundle.sh b/production/setup_src/bundle_example/create_bundle.sh
index 4a3d4c45..3b4c88ef 100644
--- a/production/setup_src/bundle_example/create_bundle.sh
+++ b/production/setup_src/bundle_example/create_bundle.sh
@@ -1,10 +1,10 @@
#!/bin/bash
-if [ ! -d $RUNTIME_DIR/install ]; then mkdir $RUNTIME_DIR/install; fi
+if [ ! -d $RUNTIME_PATH/install ]; then mkdir $RUNTIME_PATH/install; fi
echo exe ending is $EXE_END
-rm -f $RUNTIME_DIR/install/example_bundle$EXE_END
+rm -f $RUNTIME_PATH/install/example_bundle$EXE_END
-$EXECUTABLE_DIR/bundle_creator -o $RUNTIME_DIR/install/example_bundle$EXE_END -m ./example_manifest.txt
+$EXECUTABLE_DIR/bundle_creator -o $RUNTIME_PATH/install/example_bundle$EXE_END -m ./example_manifest.txt
diff --git a/production/setup_src/bundle_example/example_manifest.txt b/production/setup_src/bundle_example/example_manifest.txt
index 9a293543..e1fe2061 100644
--- a/production/setup_src/bundle_example/example_manifest.txt
+++ b/production/setup_src/bundle_example/example_manifest.txt
@@ -114,7 +114,7 @@ target=$TARGET/bytedunker$EXE_END
; operating systems and is blank for others (so far).
[using_vars]
-source=$CLAM_BINARY_DIR/value_tagger$EXE_END
+source=$CLAM_BINARIES/value_tagger$EXE_END
target=$TMP/using_varsilator$EXE_END
; variables in the source get resolved at packing time.
; variables in the target get resolved during unbundling time.
@@ -192,7 +192,7 @@ error_okay = true
; an executable program from stopping the unbundling process.
[no_replacement]
-source=$PRODUCTION_DIR/feisty_meow_config.ini
+source=$PRODUCTION_STORE/feisty_meow_config.ini
target=$TARGET/buildonia.ini
no_replace=true
; this shows how the "no_replace" macro will avoid overwriting a file if it
@@ -204,7 +204,7 @@ no_replace=true
; should be that your changes are kept.
[install_but_backup]
-source=$PRODUCTION_DIR/feisty_meow_config.ini
+source=$PRODUCTION_STORE/feisty_meow_config.ini
target=$TARGET/build_file_uhh
make_backup=t
; this simple example shows the backing up of a file before the packed
diff --git a/production/setup_src/bundle_example/makefile b/production/setup_src/bundle_example/makefile
index b4cd3cb3..3efce9bf 100644
--- a/production/setup_src/bundle_example/makefile
+++ b/production/setup_src/bundle_example/makefile
@@ -3,7 +3,7 @@ include cpp/variables.def
PROJECT = example_bundle
TYPE = hierarchy
FIRST_TARGETS += build_bundle
-CLEANUPS += $(RUNTIME_DIR)/install/example_bundle$(EXE_END)
+CLEANUPS += $(RUNTIME_PATH)/install/example_bundle$(EXE_END)
# set the unix bin variable so the bundle finds the apps.
export UNIX_BIN = /bin
diff --git a/production/setup_src/whole_build_package/create_whole_build_pack.sh b/production/setup_src/whole_build_package/create_whole_build_pack.sh
index 3c8c68fa..4327230b 100644
--- a/production/setup_src/whole_build_package/create_whole_build_pack.sh
+++ b/production/setup_src/whole_build_package/create_whole_build_pack.sh
@@ -4,7 +4,7 @@
version=$1
-INSTDIR=$RUNTIME_DIR/install
+INSTDIR=$RUNTIME_PATH/install
if [ ! -d "$INSTDIR" ]; then mkdir "$INSTDIR"; fi
# the new packages are named after the build version.
@@ -15,9 +15,9 @@ rm -f $INSTDIR/whole_build_*exe $INSTDIR/sources_*exe
echo
echo Creating source package in `basename $source_pack`
-$RUNTIME_DIR/binaries/bundle_creator -o $source_pack -m ./whole_build_manifest.txt --keyword sources
+$RUNTIME_PATH/binaries/bundle_creator -o $source_pack -m ./whole_build_manifest.txt --keyword sources
echo
echo Creating full build package in `basename $total_build`
-$RUNTIME_DIR/binaries/bundle_creator -o $total_build -m ./whole_build_manifest.txt
+$RUNTIME_PATH/binaries/bundle_creator -o $total_build -m ./whole_build_manifest.txt
diff --git a/production/setup_src/whole_build_package/makefile b/production/setup_src/whole_build_package/makefile
index 21f5d854..c8812877 100644
--- a/production/setup_src/whole_build_package/makefile
+++ b/production/setup_src/whole_build_package/makefile
@@ -2,7 +2,7 @@ include cpp/variables.def
PROJECT = Whole_Build_Pack
FIRST_TARGETS += create_package
-CLEANUPS += $(RUNTIME_DIR)/install/whole_build* $(RUNTIME_DIR)/install/sources_*
+CLEANUPS += $(RUNTIME_PATH)/install/whole_build* $(RUNTIME_PATH)/install/sources_*
TYPE = hierarchy
export TARGET=/tmp/zz_wholebuild_$(USER)
diff --git a/production/setup_src/whole_build_package/whole_build_manifest.txt b/production/setup_src/whole_build_package/whole_build_manifest.txt
index 99f3d961..8100faa6 100644
--- a/production/setup_src/whole_build_package/whole_build_manifest.txt
+++ b/production/setup_src/whole_build_package/whole_build_manifest.txt
@@ -45,7 +45,7 @@ keyword=sources
; this section is included in both types of package.
[production_inis]
-source=$PRODUCTION_DIR/*.ini
+source=$PRODUCTION_STORE/*.ini
target=$TARGET/production
keyword=sources
@@ -60,7 +60,7 @@ target=$TARGET/makefile
keyword=sources
[production_makefile]
-source=$PRODUCTION_DIR/makefile
+source=$PRODUCTION_STORE/makefile
target=$TARGET/production/makefile
keyword=sources
@@ -131,19 +131,19 @@ recurse=1
keyword=sources
[assign_bases]
-source=$PRODUCTION_DIR/assign_bases
+source=$PRODUCTION_STORE/assign_bases
target=$TARGET/production/assign_bases
recurse=1
keyword=sources
[check_versions]
-source=$PRODUCTION_DIR/check_versions
+source=$PRODUCTION_STORE/check_versions
target=$TARGET/production/check_versions
recurse=1
keyword=sources
[setup_src]
-source=$PRODUCTION_DIR/setup_src
+source=$PRODUCTION_STORE/setup_src
target=$TARGET/production/setup_src
recurse=1
keyword=sources
@@ -151,22 +151,22 @@ keyword=sources
; this section is only included in the full package (not in sources).
[3rdparty]
-source=$PRODUCTION_DIR/3rdparty
+source=$PRODUCTION_STORE/3rdparty
target=$TARGET/production/3rdparty
recurse=1
[binaries]
-source=$RUNTIME_DIR/binaries
+source=$RUNTIME_PATH/binaries
target=$TARGET/runtime/binaries
recurse=1
[clam_bin]
-source=$RUNTIME_DIR/clam_bin
+source=$RUNTIME_PATH/clam_bin
target=$TARGET/runtime/clam_bin
recurse=1
[packages]
-source=$RUNTIME_DIR/packages
+source=$RUNTIME_PATH/packages
target=$TARGET/runtime/packages
recurse=1
diff --git a/scripts/archival/pack_feisty_meow.sh b/scripts/archival/pack_feisty_meow.sh
index e5166685..67a52bf9 100644
--- a/scripts/archival/pack_feisty_meow.sh
+++ b/scripts/archival/pack_feisty_meow.sh
@@ -18,7 +18,7 @@ tar -h -czf $TEMPO_FILE $base_dir $XC"*/*.tar.gz" $XC"*/*.zip" $XC"*/waste/*" $X
# now move the newest version into its resting place. this prepares the
# feisty_meow package for uploading.
-mv -v $TEMPO_FILE $WEB_DIR/feistymeow.org/releases/feisty_meow_codebase_$(date_stringer).tar.gz
+mv -v $TEMPO_FILE $WEBBED_SITES/feistymeow.org/releases/feisty_meow_codebase_$(date_stringer).tar.gz
popd
diff --git a/scripts/clam/badness_catcher.sh b/scripts/clam/badness_catcher.sh
index f25746f1..cc523e8d 100755
--- a/scripts/clam/badness_catcher.sh
+++ b/scripts/clam/badness_catcher.sh
@@ -19,6 +19,6 @@ echo "Error in project: \"$PROJECT\""
echo " command was: $*"
echo
echo "======================="
-source $CLAM_DIR/exit_make.sh
+source $CLAM_SCRIPTS/exit_make.sh
exit $ERR
diff --git a/scripts/clam/clean_subdirs.sh b/scripts/clam/clean_subdirs.sh
index 45d2c1e1..a438cc08 100755
--- a/scripts/clam/clean_subdirs.sh
+++ b/scripts/clam/clean_subdirs.sh
@@ -13,7 +13,7 @@ function clean_subdirectories()
if [ -f "$smoot87/makefile" ]; then
#echo -e "\n\n[[inside barriers, with filename=$burlap51 and all conditions met]]\n\n"
pushd "$smoot87" &>/dev/null
- make --silent -I "$CLAM_DIR" NOT_FIRST_MAKE=t clean
+ make --silent -I "$CLAM_SCRIPTS" NOT_FIRST_MAKE=t clean
popd &>/dev/null
else
echo "(skipping directory $smoot87)"
diff --git a/scripts/clam/cpp/buildor_gen_deps.sh b/scripts/clam/cpp/buildor_gen_deps.sh
index c70fe48b..09b328c2 100755
--- a/scripts/clam/cpp/buildor_gen_deps.sh
+++ b/scripts/clam/cpp/buildor_gen_deps.sh
@@ -236,10 +236,10 @@ echo "dependent on: $(basename "$dirtmp")/$basetmp"
##########################################################################
- local current_includes="$(mktemp $TEMPORARIES_DIR/zz_buildor_deps4-$base.XXXXXX)"
+ local current_includes="$(mktemp $TEMPORARIES_PILE/zz_buildor_deps4-$base.XXXXXX)"
rm -f "$current_includes"
- local partial_file="$(mktemp $TEMPORARIES_DIR/zz_buildor_deps5-$base.XXXXXX)"
+ local partial_file="$(mktemp $TEMPORARIES_PILE/zz_buildor_deps5-$base.XXXXXX)"
rm -f "$partial_file"
# find all the includes in this file and save to the temp file.
@@ -404,7 +404,7 @@ function write_new_version {
#echo "would write deps to: $code_file"
#echo ${dependency_accumulator[*]}
- local replacement_file="$(mktemp $TEMPORARIES_DIR/zz_buildor_deps3.XXXXXX)"
+ local replacement_file="$(mktemp $TEMPORARIES_PILE/zz_buildor_deps3.XXXXXX)"
# blanks is a list of blank lines that we save up in between actual content.
# if we don't hold onto them, we can have the effect of "walking" the static
@@ -436,7 +436,7 @@ function write_new_version {
echo -e "$opening_guard_line" >>"$replacement_file"
# now accumulate just the dependencies for a bit.
- local pending_deps="$(mktemp $TEMPORARIES_DIR/zz_buildor_deps2.XXXXXX)"
+ local pending_deps="$(mktemp $TEMPORARIES_PILE/zz_buildor_deps2.XXXXXX)"
rm -f "$pending_deps"
# iterate across all the dependencies we found.
@@ -517,7 +517,7 @@ for curr_parm in $*; do
# set the directory to that absolute path.
curr_parm="$prohibited_directory"
#echo "curr_parm: $curr_parm"
- outfile="$(mktemp $TEMPORARIES_DIR/zz_buildor_deps1.XXXXXX)"
+ outfile="$(mktemp $TEMPORARIES_PILE/zz_buildor_deps1.XXXXXX)"
find "$curr_parm" -iname "*.cpp" >"$outfile"
while read -r line_found; do
if [ $? != 0 ]; then break; fi
diff --git a/scripts/clam/cpp/ms_manifest.sh b/scripts/clam/cpp/ms_manifest.sh
index a4ac61d1..94f0f669 100755
--- a/scripts/clam/cpp/ms_manifest.sh
+++ b/scripts/clam/cpp/ms_manifest.sh
@@ -4,15 +4,15 @@
target=$1; shift
where=$1; shift
if [ -z "$WIN32_MANIFEST_FILE" ]; then
- WIN32_MANIFEST_FILE=$CLAM_DIR/cpp/ms_manifests/security_manifest.txt
+ WIN32_MANIFEST_FILE=$CLAM_SCRIPTS/cpp/ms_manifests/security_manifest.txt
fi
for ((count=1 ; count <= 10; count++)); do
error_val=0
if [ -f "$target.manifest" -a -f "$target" ]; then
- bash $BUILD_SCRIPTS_DIR/wrapdoze.sh mt -manifest $target.manifest $WIN32_MANIFEST_FILE -outputresource:$target\;$where >/dev/null
+ bash $BUILD_SCRIPTS_PATH/wrapdoze.sh mt -manifest $target.manifest $WIN32_MANIFEST_FILE -outputresource:$target\;$where >/dev/null
error_val=$?
elif [ -f "$target" ]; then
- bash $BUILD_SCRIPTS_DIR/wrapdoze.sh mt -manifest $WIN32_MANIFEST_FILE -outputresource:$target\;$where >/dev/null
+ bash $BUILD_SCRIPTS_PATH/wrapdoze.sh mt -manifest $WIN32_MANIFEST_FILE -outputresource:$target\;$where >/dev/null
error_val=$?
else
echo skipping manifest generation for $target.
diff --git a/scripts/clam/cpp/postconditions.sh b/scripts/clam/cpp/postconditions.sh
index 1c1490bf..174529a2 100755
--- a/scripts/clam/cpp/postconditions.sh
+++ b/scripts/clam/cpp/postconditions.sh
@@ -10,7 +10,7 @@ fi
if [ -f $FAILURE_FILE ]; then
echo Postconditions will not promote due to a failure:
cat $FAILURE_FILE
- . $CLAM_DIR/exit_make.sh
+ . $CLAM_SCRIPTS/exit_make.sh
fi
# make sure that we actually did something during the make.
@@ -23,9 +23,9 @@ fi
for i in *.resources; do rm -f "$i"; done
# causes the shell to quit.
-DIE="source $CLAM_DIR/exit_make.sh"
+DIE="source $CLAM_SCRIPTS/exit_make.sh"
-if [ ! -d $TARGETS_DIR ]; then mkdir -p $TARGETS_DIR; fi
+if [ ! -d $TARGETS_STORE ]; then mkdir -p $TARGETS_STORE; fi
if [ "$TYPE" = "library" ]; then
@@ -61,6 +61,6 @@ elif [ "$TYPE" = "hierarchy" ]; then
else
echo "Unknown type for project [$TYPE]; cancelling postconditions!"
- source $CLAM_DIR/exit_make.sh
+ source $CLAM_SCRIPTS/exit_make.sh
fi
diff --git a/scripts/clam/cpp/preconditions.sh b/scripts/clam/cpp/preconditions.sh
index 1197a222..771f5a30 100755
--- a/scripts/clam/cpp/preconditions.sh
+++ b/scripts/clam/cpp/preconditions.sh
@@ -12,7 +12,7 @@ if [ ! -z "$CLEAN" ]; then
fi
# make sure generated files have a home.
-if [ ! -d $TARGETS_DIR ]; then mkdir -p $TARGETS_DIR; fi
+if [ ! -d $TARGETS_STORE ]; then mkdir -p $TARGETS_STORE; fi
# create the generated files storage area.
if [ ! -d $OUTPUT_ROOT ]; then mkdir -p $OUTPUT_ROOT; fi
# create the top level object directory if it doesn't exist.
@@ -33,7 +33,7 @@ if [ ! -d $STATIC_LIBRARY_DIR ]; then mkdir -p $STATIC_LIBRARY_DIR; fi
# set versions on any extras that were specified in the makefile.
if [ ! -z "$EXTRA_VERSIONS" ]; then
for i in $EXTRA_VERSIONS; do
- $CLAM_BINARY_DIR/version_stamper$EXE_END $i $PARAMETER_FILE
+ $CLAM_BINARIES/version_stamper$EXE_END $i $PARAMETER_FILE
done
fi
diff --git a/scripts/clam/cpp/rebuild_oldies.sh b/scripts/clam/cpp/rebuild_oldies.sh
index fa3b4003..0edc0072 100755
--- a/scripts/clam/cpp/rebuild_oldies.sh
+++ b/scripts/clam/cpp/rebuild_oldies.sh
@@ -6,7 +6,7 @@ if [ -f "$BUILD_LIST_FILE" ]; then
eval "${@}"
rm -f $BUILD_LIST_FILE $BUILD_WHACK_FILE
if [ $? -ne 0 ]; then
- . "$CLAM_DIR/exit_make.sh"
+ . "$CLAM_SCRIPTS/exit_make.sh"
fi
fi
diff --git a/scripts/clam/cpp/rules.def b/scripts/clam/cpp/rules.def
index acbf13c2..85602532 100644
--- a/scripts/clam/cpp/rules.def
+++ b/scripts/clam/cpp/rules.def
@@ -415,13 +415,13 @@ ACTUAL_LAST_TARGETS = post_compilation $(LAST_TARGETS)
# without hosing it up.
%.nil:
ifeq "$(NO_COMPILE)" ""
- $(CATCHER)$(CC) -c $(CLAM_DIR)/cpp/blank_target.c -o $@
+ $(CATCHER)$(CC) -c $(CLAM_SCRIPTS)/cpp/blank_target.c -o $@
endif
%.bad:
@echo There is a problem with the makefile in the SOURCE variable.
@echo The offending item is: $@
- $(HIDESH)$(CLAM_DIR)/exit_make.sh
+ $(HIDESH)$(CLAM_SCRIPTS)/exit_make.sh
## faked debug object.
#%.obj: %.cpp
@@ -434,7 +434,7 @@ ifeq "$(CLEAN)" ""
# recreate dependencies for static applications.
%.gendeps: %.cpp
@echo "Generating Static Deps: $*.cpp"
- $(CATCHER)$(CLAM_DIR)/cpp/buildor_gen_deps.sh "$*.cpp"
+ $(CATCHER)$(CLAM_SCRIPTS)/cpp/buildor_gen_deps.sh "$*.cpp"
endif
############################################################################
@@ -540,7 +540,7 @@ $(STATIC_LIBRARY_DIR)/%.library: $(ACTUAL_OBJECTS:%=$(OBJECT_DIR)/%) $(ACTUAL_LO
$(HIDER)echo Building Static Library [$(notdir $@)]
@echo $@ >$(DIRTY_FILE)
ifeq "$(COMPILER)" "VISUAL_CPP"
- $(HIDESH)-c 'if [ -f $(BUILD_LIST_FILE) ]; then $(SHELL) $(CLAM_DIR)/cpp/rebuild_oldies.sh $(MULTI_BUILD_CMD); fi'
+ $(HIDESH)-c 'if [ -f $(BUILD_LIST_FILE) ]; then $(SHELL) $(CLAM_SCRIPTS)/cpp/rebuild_oldies.sh $(MULTI_BUILD_CMD); fi'
endif
$(CATCHER)$(LIBRARY_TOOL) $(LIBRARIAN_FLAGS) $(CREATE_LIBRARY_FLAG)$@ $(ACTUAL_OBJECTS:%=$(OBJECT_DIR)/%)
ifneq "$(OP_SYSTEM)" "UNIX"
@@ -573,17 +573,17 @@ $(DYNAMIC_LIBRARY_DIR)/%.dll: $(ACTUAL_OBJECTS:%=$(OBJECT_DIR)/%) $(ACTUAL_LOCAL
$(HIDER)echo Building Dynamic Library [$(notdir $@)]
@echo $@ >$(DIRTY_FILE)
ifeq "$(COMPILER)" "VISUAL_CPP"
- $(HIDESH)-c 'if [ -f $(BUILD_LIST_FILE) ]; then $(SHELL) $(CLAM_DIR)/cpp/rebuild_oldies.sh $(MULTI_BUILD_CMD); fi'
+ $(HIDESH)-c 'if [ -f $(BUILD_LIST_FILE) ]; then $(SHELL) $(CLAM_SCRIPTS)/cpp/rebuild_oldies.sh $(MULTI_BUILD_CMD); fi'
endif
$(HIDER)rm -f $(@:%.dll=%.lib)
echo about to run link tool.
$(CATCHER)$(LINK_TOOL) $(LINKER_OUTPUT_FLAG)$@ -dll $(LOAD_FLAG_PREFIX) $(ACTUAL_OBJECTS:%=$(OBJECT_DIR)/%) $(ACTUAL_RESX_FLAGS) $(ACTUAL_LOCAL_LIBS:%=$(LIBRARY_NAME_FLAG)$(LIB_PREFIX)%$(LIB_ENDING)) $(LOAD_FLAG_SUFFIX)
echo ran link tool.
ifeq "$(COMPILER_VERSION)" "8"
- $(HIDESH)$(CLAM_DIR)/cpp/ms_manifest.sh "$@" "2"
+ $(HIDESH)$(CLAM_SCRIPTS)/cpp/ms_manifest.sh "$@" "2"
endif
ifeq "$(COMPILER_VERSION)" "10"
- $(HIDESH)$(CLAM_DIR)/cpp/ms_manifest.sh "$@" "2"
+ $(HIDESH)$(CLAM_SCRIPTS)/cpp/ms_manifest.sh "$@" "2"
endif
ifneq "$(VCPP_VISTA_ICON)" ""
$(HIDER)ReplaceVistaIcon "$@" "$(VCPP_VISTA_ICON)"
@@ -619,15 +619,15 @@ $(EXECUTABLE_DIR)/%.exe: $(OBJECT_DIR)/%.obj $(ACTUAL_OBJECTS:%=$(OBJECT_DIR)/%)
$(HIDER)echo Building Application [$(notdir $@)]
@echo $@ >$(DIRTY_FILE)
ifeq "$(COMPILER)" "VISUAL_CPP"
- $(HIDESH)-c 'if [ -f $(BUILD_LIST_FILE) ]; then $(SHELL) $(CLAM_DIR)/cpp/rebuild_oldies.sh $(MULTI_BUILD_CMD); fi'
+ $(HIDESH)-c 'if [ -f $(BUILD_LIST_FILE) ]; then $(SHELL) $(CLAM_SCRIPTS)/cpp/rebuild_oldies.sh $(MULTI_BUILD_CMD); fi'
endif
$(CATCHER)$(LINK_TOOL) $(EXE_FLAGS) $(LOAD_FLAG_PREFIX) $< $(ACTUAL_OBJECTS:%=$(OBJECT_DIR)/%) $(ACTUAL_RESX_FLAGS) $(ACTUAL_LOCAL_LIBS:%=$(LIBRARY_NAME_FLAG)$(LIB_PREFIX)%$(LIB_ENDING)) $(LOAD_FLAG_SUFFIX) $(LINKER_OUTPUT_FLAG)$@
#$(^:force_rebuild=)
ifeq "$(COMPILER_VERSION)" "8"
- $(HIDESH)$(CLAM_DIR)/cpp/ms_manifest.sh "$@" "1"
+ $(HIDESH)$(CLAM_SCRIPTS)/cpp/ms_manifest.sh "$@" "1"
endif
ifeq "$(COMPILER_VERSION)" "10"
- $(HIDESH)$(CLAM_DIR)/cpp/ms_manifest.sh "$@" "1"
+ $(HIDESH)$(CLAM_SCRIPTS)/cpp/ms_manifest.sh "$@" "1"
endif
ifneq "$(VCPP_VISTA_ICON)" ""
$(HIDER)ReplaceVistaIcon "$@" "$(VCPP_VISTA_ICON)"
@@ -678,7 +678,7 @@ ifeq "$(OMIT_VERSIONS)" ""
ifneq "$(VERSION_RC_ROOT)" ""
# only redo the version resource if it or version.ini is out of date.
%_version.rc: version.ini $(PARAMETER_FILE)
- $(CATCHER)$(CLAM_BINARY_DIR)/version_stamper$(EXE_END) . $(PARAMETER_FILE)
+ $(CATCHER)$(CLAM_BINARIES)/version_stamper$(EXE_END) . $(PARAMETER_FILE)
endif
endif
@@ -752,11 +752,11 @@ else
endif
endif
@echo Dependencies [$(notdir $@)]
- -$(HIDESH)$(CLAM_DIR)/cpp/preconditions.sh
+ -$(HIDESH)$(CLAM_SCRIPTS)/cpp/preconditions.sh
@touch $@
# @echo dep adds: $(DEPENDENCY_ADDITIONS)
- @$(CLAM_BINARY_DIR)/makedep$(EXE_END) $(DEPENDENCY_DEFINITIONS:%=-D%) $(DEPENDENCY_ADDITIONS) -f$@ -o.obj -p$(OBJECT_DIR)/ -w 420 $(COMPILER_HEADER_DIR:%=-X%) $(THIRD_PARTY_DIR:%=-X%) -- $(COMPILER_FLAGS) $(SOURCE) $(EXE_CPPS)
-# $(CATCHER)$(CLAM_BINARY_DIR)/makedep$(EXE_END) $(DEPENDENCY_DEFINITIONS:%=-D%) $(DEPENDENCY_ADDITIONS) -f$@ -o.obj -p$(OBJECT_DIR)/ -w 420 $(COMPILER_HEADER_DIR:%=-X%) $(THIRD_PARTY_DIR:%=-X%) -- $(COMPILER_FLAGS) $(SOURCE) $(EXE_CPPS)
+ @$(CLAM_BINARIES)/makedep$(EXE_END) $(DEPENDENCY_DEFINITIONS:%=-D%) $(DEPENDENCY_ADDITIONS) -f$@ -o.obj -p$(OBJECT_DIR)/ -w 420 $(COMPILER_HEADER_DIR:%=-X%) $(THIRD_PARTY_DIR:%=-X%) -- $(COMPILER_FLAGS) $(SOURCE) $(EXE_CPPS)
+# $(CATCHER)$(CLAM_BINARIES)/makedep$(EXE_END) $(DEPENDENCY_DEFINITIONS:%=-D%) $(DEPENDENCY_ADDITIONS) -f$@ -o.obj -p$(OBJECT_DIR)/ -w 420 $(COMPILER_HEADER_DIR:%=-X%) $(THIRD_PARTY_DIR:%=-X%) -- $(COMPILER_FLAGS) $(SOURCE) $(EXE_CPPS)
@echo $@ >$(SUBMAKE_FLAG)
endif # non-compile.
else # cleaning.
@@ -771,8 +771,8 @@ endif # no-deps.
# examines the required variables and complains if they're missing.
check_requirements:
- $(HIDESH) -c 'if [ -z "$(PROJECT)" ]; then echo the PROJECT variable is not defined!; . $(CLAM_DIR)/exit_make.sh; fi'
- $(HIDESH) -c 'if [ -z "$(TYPE)" ]; then echo the TYPE variable is not defined!; . $(CLAM_DIR)/exit_make.sh; fi'
+ $(HIDESH) -c 'if [ -z "$(PROJECT)" ]; then echo the PROJECT variable is not defined!; . $(CLAM_SCRIPTS)/exit_make.sh; fi'
+ $(HIDESH) -c 'if [ -z "$(TYPE)" ]; then echo the TYPE variable is not defined!; . $(CLAM_SCRIPTS)/exit_make.sh; fi'
############################################################################
@@ -794,7 +794,7 @@ endif
# calls the script for preparing output directories and such.
pre_compilation:
- $(HIDESH)$(CLAM_DIR)/cpp/preconditions.sh
+ $(HIDESH)$(CLAM_SCRIPTS)/cpp/preconditions.sh
############################################################################
@@ -802,7 +802,7 @@ pre_compilation:
# we don't bother reporting errors from touch since there will sometimes
# not be any objects in the final directory.
post_compilation:
- $(HIDESH)$(CLAM_DIR)/cpp/postconditions.sh
+ $(HIDESH)$(CLAM_SCRIPTS)/cpp/postconditions.sh
############################################################################
diff --git a/scripts/clam/cpp/variables.def b/scripts/clam/cpp/variables.def
index caf69cba..60fcc7bc 100644
--- a/scripts/clam/cpp/variables.def
+++ b/scripts/clam/cpp/variables.def
@@ -11,7 +11,7 @@ ifneq "$(BUILD_PARAMETER_FILE)" ""
endif
ifeq "$(PARAMETER_FILE)" ""
# last ditch attempt to get one that will work.
- export PARAMETER_FILE = $(PRODUCTION_DIR)/feisty_meow_config.ini
+ export PARAMETER_FILE = $(PRODUCTION_STORE)/feisty_meow_config.ini
endif
###############################################################################
@@ -31,7 +31,7 @@ include variables.def
# endif
#endif
-#export CLAM_BINARY_DIR = $(CLAM_DIR)/../bin
+#export CLAM_BINARIES = $(CLAM_SCRIPTS)/../bin
###############################################################################
@@ -184,7 +184,7 @@ FLAG_FILES += $(BUILD_LIST_FILE) $(BUILD_WHACK_FILE)
# "THIRD_PARTY_DIR" is the root of our support libraries.
export THIRD_PARTY_DIR
ifeq "$(THIRD_PARTY_DIR)" ""
- export THIRD_PARTY_DIR := "$(PRODUCTION_DIR)/3rdparty"
+ export THIRD_PARTY_DIR := "$(PRODUCTION_STORE)/3rdparty"
endif
# "OUTPUT_ROOT" is the root of all output directories for objects and other
@@ -209,7 +209,7 @@ export BASE_OUTPUT_PATH = $(OUTPUT_ROOT)/$(CPU_BUILD_DIR)
# special case when doing arm-linux builds
ifeq "$(COMPILER)" "GNU_ARM_LINUX"
- export TARGETS_DIR = $(FEISTY_MEOW_APEX)/$(CPU_BUILD_DIR)
+ export TARGETS_STORE = $(FEISTY_MEOW_APEX)/$(CPU_BUILD_DIR)
# special output directory for firmware does not include CPU name because
# the repository already include the CPU name
BASE_OUTPUT_PATH = $(OUTPUT_ROOT)
@@ -223,9 +223,9 @@ export OUTPUT_PATH = $(BASE_OUTPUT_PATH)/$(PROJECT)
export OBJECT_DIR = $(OUTPUT_PATH)
# These specify where files are to be created or located for our local build.
-export EXECUTABLE_DIR = $(TARGETS_DIR)
-export DYNAMIC_LIBRARY_DIR = $(TARGETS_DIR)
-export STATIC_LIBRARY_DIR = $(TARGETS_DIR)
+export EXECUTABLE_DIR = $(TARGETS_STORE)
+export DYNAMIC_LIBRARY_DIR = $(TARGETS_STORE)
+export STATIC_LIBRARY_DIR = $(TARGETS_STORE)
# "HEADER_SEARCH_PATH" is where the class interface files are to be found.
#HEADER_SEARCH_PATH =
@@ -404,7 +404,7 @@ LIBRARY_PATH_FLAG = -L
# the root name of the version file. This is currently irrelevant on
# non-win32 platforms.
-VERSION_RC_ROOT = $(shell $(SHELL) $(CLAM_DIR)/cpp/rc_name.sh)
+VERSION_RC_ROOT = $(shell $(SHELL) $(CLAM_SCRIPTS)/cpp/rc_name.sh)
ifneq "$(CONSOLE_MODE)" ""
# this definition can be used to signal different behavior when the app is
@@ -468,7 +468,7 @@ ifeq "$(COMPILER)" "GNU_LINUX"
PLATFORM_ADD_IN = linux_
ARCHITECTURE = $(shell machine 2>/dev/null || arch 2>/dev/null || echo i686)
- export COMPILER_VERSION = $(shell $(SHELL) $(CLAM_DIR)/cpp/get_version.sh $(COMPILER) $(COMPILER_ROOT_DIR) )
+ export COMPILER_VERSION = $(shell $(SHELL) $(CLAM_SCRIPTS)/cpp/get_version.sh $(COMPILER) $(COMPILER_ROOT_DIR) )
DEFINITIONS += _FILE_OFFSET_BITS=64
@@ -551,7 +551,7 @@ ifeq "$(COMPILER)" "GNU_ARM_LINUX"
CC = $(COMPILER_ROOT_DIR)/bin/g++
PLATFORM_ADD_IN = linux_
- export COMPILER_VERSION = $(shell $(SHELL) $(CLAM_DIR)/cpp/get_version.sh $(COMPILER) $(COMPILER_ROOT_DIR) )
+ export COMPILER_VERSION = $(shell $(SHELL) $(CLAM_SCRIPTS)/cpp/get_version.sh $(COMPILER) $(COMPILER_ROOT_DIR) )
SNAPGEAR_ROOT_DIR = $(HOME)/snapgear
@@ -598,7 +598,7 @@ ifeq "$(COMPILER)" "GNU_WINDOWS"
COMPILER_ROOT_DIR = $(CYGROOT)
endif
- export COMPILER_VERSION = $(shell $(SHELL) $(CLAM_DIR)/cpp/get_version.sh $(COMPILER) $(COMPILER_ROOT_DIR) )
+ export COMPILER_VERSION = $(shell $(SHELL) $(CLAM_SCRIPTS)/cpp/get_version.sh $(COMPILER) $(COMPILER_ROOT_DIR) )
RC := $(COMPILER_ROOT_DIR)/bin/windres
PLATFORM_ADD_IN = w32_
@@ -674,7 +674,7 @@ ifeq "$(COMPILER)" "VISUAL_CPP"
# calculate the visual studio root directory.
ifeq "$(VIS_STU_ROOT)" ""
- export VIS_STU_ROOT := $(shell $(SHELL) $(CLAM_DIR)/cpp/ms_root_dir.sh )
+ export VIS_STU_ROOT := $(shell $(SHELL) $(CLAM_SCRIPTS)/cpp/ms_root_dir.sh )
endif
ifneq "$(VIS_STU_ROOT)" ""
export COMPILER_ROOT_DIR = $(VIS_STU_ROOT)/VC
@@ -687,16 +687,16 @@ ifeq "$(COMPILER)" "VISUAL_CPP"
endif
# redo the compiler version with our new info.
- export COMPILER_VERSION := $(shell $(SHELL) $(CLAM_DIR)/cpp/get_version.sh $(COMPILER) $(COMPILER_ROOT_DIR) )
+ export COMPILER_VERSION := $(shell $(SHELL) $(CLAM_SCRIPTS)/cpp/get_version.sh $(COMPILER) $(COMPILER_ROOT_DIR) )
# set up a directory for debugging files to be stored. these are not
# moved with the postconditions--they are generated in place.
- export PDB_DIR = $(TARGETS_DIR)
+ export PDB_DIR = $(TARGETS_STORE)
# set these way up here so we can override them later.
- CC = $(BUILD_SCRIPTS_DIR)/wrapdoze.sh $(COMPILER_ROOT_DIR)/bin/cl.exe
- LINK_TOOL = $(BUILD_SCRIPTS_DIR)/wrapdoze.sh $(COMPILER_ROOT_DIR)/bin/link.exe
- LIBRARY_TOOL = $(BUILD_SCRIPTS_DIR)/wrapdoze.sh $(COMPILER_ROOT_DIR)/bin/lib
+ CC = $(BUILD_SCRIPTS_PATH)/wrapdoze.sh $(COMPILER_ROOT_DIR)/bin/cl.exe
+ LINK_TOOL = $(BUILD_SCRIPTS_PATH)/wrapdoze.sh $(COMPILER_ROOT_DIR)/bin/link.exe
+ LIBRARY_TOOL = $(BUILD_SCRIPTS_PATH)/wrapdoze.sh $(COMPILER_ROOT_DIR)/bin/lib
# This is needed to protect against the use of 64-bit time_t structure
# on windows. We are casting to time_t from a 32-bit structure.
@@ -706,19 +706,19 @@ ifeq "$(COMPILER)" "VISUAL_CPP"
ifeq "$(COMPILER_VERSION)" "6"
COMPILER_HEADER_DIR = $(COMPILER_ROOT_DIR)/include $(COMPILER_ROOT_DIR)/atl/include
COMPILER_LIBRARY_DIR = $(COMPILER_ROOT_DIR)/lib $(COMPILER_ROOT_DIR)/atl/lib
- RC = $(BUILD_SCRIPTS_DIR)/wrapdoze.sh $(COMPILER_ROOT_DIR)/../common/msdev98/bin/rc
+ RC = $(BUILD_SCRIPTS_PATH)/wrapdoze.sh $(COMPILER_ROOT_DIR)/../common/msdev98/bin/rc
endif
ifeq "$(COMPILER_VERSION)" "7"
COMPILER_HEADER_DIR = $(COMPILER_ROOT_DIR)/include $(COMPILER_ROOT_DIR)/atlmfc/include $(COMPILER_ROOT_DIR)/platformsdk/include $(FRAMEWORK_DIR)
COMPILER_LIBRARY_DIR = $(COMPILER_ROOT_DIR)/lib $(COMPILER_ROOT_DIR)/atlmfc/lib $(COMPILER_ROOT_DIR)/platformsdk/lib
- RC = $(BUILD_SCRIPTS_DIR)/wrapdoze.sh $(COMPILER_ROOT_DIR)/bin/rc
+ RC = $(BUILD_SCRIPTS_PATH)/wrapdoze.sh $(COMPILER_ROOT_DIR)/bin/rc
COMPILER_FLAGS += -Zc:forScope
# turn on proper loop scoping.
endif
ifeq "$(COMPILER_VERSION)" "8"
COMPILER_HEADER_DIR = $(COMPILER_ROOT_DIR)/include $(COMPILER_ROOT_DIR)/atlmfc/include $(COMPILER_ROOT_DIR)/platformsdk/include $(FRAMEWORK_DIR)
COMPILER_LIBRARY_DIR = $(COMPILER_ROOT_DIR)/lib $(COMPILER_ROOT_DIR)/atlmfc/lib $(COMPILER_ROOT_DIR)/platformsdk/lib
- RC = $(BUILD_SCRIPTS_DIR)/wrapdoze.sh $(COMPILER_ROOT_DIR)/bin/rc
+ RC = $(BUILD_SCRIPTS_PATH)/wrapdoze.sh $(COMPILER_ROOT_DIR)/bin/rc
COMPILER_FLAGS += -Zc:forScope
# turn on proper loop scoping.
DEFINITIONS += _WIN32_WINNT=0x501
@@ -734,7 +734,7 @@ ifeq "$(COMPILER)" "VISUAL_CPP"
COMPILER_LIBRARY_DIR = $(COMPILER_ROOT_DIR)/lib $(COMPILER_ROOT_DIR)/atlmfc/lib $(PLATYPUS)/lib
DEFINITIONS += _WIN32_WINNT=0x501
DEPENDENCY_DEFINITIONS += _WIN32_WINNT=0x501
- RC = $(BUILD_SCRIPTS_DIR)/wrapdoze.sh $(PLATYPUS)/bin/rc
+ RC = $(BUILD_SCRIPTS_PATH)/wrapdoze.sh $(PLATYPUS)/bin/rc
COMPILER_FLAGS += -Zc:forScope
# turn on proper loop scoping.
endif
@@ -920,7 +920,7 @@ ifeq "$(COMPILER)" "GNU_DARWIN"
ARCHITECTURE = $(shell machine 2>/dev/null || arch 2>/dev/null || echo i686)
# COMPILER_FLAGS += -fgnu-runtime
- export COMPILER_VERSION = $(shell $(SHELL) $(CLAM_DIR)/cpp/get_version.sh $(COMPILER) $(COMPILER_ROOT_DIR) )
+ export COMPILER_VERSION = $(shell $(SHELL) $(CLAM_SCRIPTS)/cpp/get_version.sh $(COMPILER) $(COMPILER_ROOT_DIR) )
DEFINITIONS += _FILE_OFFSET_BITS=64
diff --git a/scripts/clam/dotnet-retired/postconditions.sh b/scripts/clam/dotnet-retired/postconditions.sh
index 1670e27e..9d145243 100644
--- a/scripts/clam/dotnet-retired/postconditions.sh
+++ b/scripts/clam/dotnet-retired/postconditions.sh
@@ -5,7 +5,7 @@
if [ -f $FAILURE_FILE ]; then
echo Postconditions will not promote due to a failure:
cat $FAILURE_FILE
- . $CLAM_DIR/exit_make.sh
+ . $CLAM_SCRIPTS/exit_make.sh
fi
# make sure that we actually did something during the make.
@@ -22,7 +22,7 @@ for i in *.resources; do rm -f "$i"; done
# these variables define the locations for final products. all of them
# descend from the root of the repository.
-ROOT=$TARGETS_DIR
+ROOT=$TARGETS_STORE
LIB_DIR=$ROOT/lib
DLL_DIR=$ROOT/dll
EXE_DIR=$ROOT/exe
@@ -30,7 +30,7 @@ TEST_ROOT=$ROOT/tests
TEST_DIR=$TEST_ROOT/$PROJECT
# causes the shell to quit.
-DIE=". $CLAM_DIR/exit_make.sh"
+DIE=". $CLAM_SCRIPTS/exit_make.sh"
if [ "$TYPE" = "library" ]; then
@@ -102,6 +102,6 @@ elif [ "$TYPE" = "test" ]; then
else
echo "Unknown type for project [$TYPE]; cancelling postconditions!"
- . $CLAM_DIR/exit_make.sh
+ . $CLAM_SCRIPTS/exit_make.sh
fi
diff --git a/scripts/clam/dotnet-retired/preconditions.sh b/scripts/clam/dotnet-retired/preconditions.sh
index a020b4ef..cdf66d75 100644
--- a/scripts/clam/dotnet-retired/preconditions.sh
+++ b/scripts/clam/dotnet-retired/preconditions.sh
@@ -6,7 +6,7 @@ if [ ! -d $FEISTY_MEOW_APEX ]; then mkdir -p $FEISTY_MEOW_APEX; fi
# make sure our temp directory is there.
if [ ! -d $CLAM_TMP ]; then mkdir -p $CLAM_TMP; fi
# make sure the generated files have a home.
-if [ ! -d $TARGETS_DIR ]; then mkdir -p $TARGETS_DIR; fi
+if [ ! -d $TARGETS_STORE ]; then mkdir -p $TARGETS_STORE; fi
# create the generated files storage area.
if [ ! -d $OUTPUT_ROOT ]; then mkdir -p $OUTPUT_ROOT; fi
# create the top level object directory if it doesn't exist.
@@ -26,7 +26,7 @@ if [ ! -d $STATIC_LIBRARY_DIR ]; then mkdir -p $STATIC_LIBRARY_DIR; fi
# set versions on any extras that were specified in the makefile.
if [ ! -z "$EXTRA_VERSIONS" ]; then
- for i in $EXTRA_VERSIONS; do $CLAM_BINARY_DIR/version_stamper$EXE_END $i $PARAMETER_FILE; done
+ for i in $EXTRA_VERSIONS; do $CLAM_BINARIES/version_stamper$EXE_END $i $PARAMETER_FILE; done
fi
# create all the directories that objects will go into.
diff --git a/scripts/clam/dotnet-retired/rules.def b/scripts/clam/dotnet-retired/rules.def
index c58d1d99..9ab0aaaf 100644
--- a/scripts/clam/dotnet-retired/rules.def
+++ b/scripts/clam/dotnet-retired/rules.def
@@ -18,7 +18,7 @@
# Modify the output directory for executable files if we're building a
# test project.
ifeq "$(TYPE)" "test"
- EXECUTABLE_DIR = $(TARGETS_DIR)/tests/$(PROJECT)
+ EXECUTABLE_DIR = $(TARGETS_STORE)/tests/$(PROJECT)
ifneq "$(CONSOLE_MODE)" ""
COMPILER_FLAGS += -target:exe
else
@@ -207,7 +207,7 @@ ifeq "$(OMIT_VERSIONS)" ""
ifneq "$(VERSION_RC_ROOT)" ""
# only redo the version resource if it or version.ini is out of date.
%_version.rc: version.ini $(PARAMETER_FILE)
- $(CATCHER)$(CLAM_BINARY_DIR)/version_stamper$(EXE_END) . $(PARAMETER_FILE)
+ $(CATCHER)$(CLAM_BINARIES)/version_stamper$(EXE_END) . $(PARAMETER_FILE)
endif
endif
@@ -230,14 +230,14 @@ include rules.def
# examines the required variables and complains if they're missing.
check_requirements:
- $(HIDESH) -c 'if [ -z "$(PROJECT)" ]; then echo the PROJECT variable is not defined!; . $(CLAM_DIR)/exit_make.sh; fi'
- $(HIDESH) -c 'if [ -z "$(TYPE)" ]; then echo the TYPE variable is not defined!; . $(CLAM_DIR)/exit_make.sh; fi'
+ $(HIDESH) -c 'if [ -z "$(PROJECT)" ]; then echo the PROJECT variable is not defined!; . $(CLAM_SCRIPTS)/exit_make.sh; fi'
+ $(HIDESH) -c 'if [ -z "$(TYPE)" ]; then echo the TYPE variable is not defined!; . $(CLAM_SCRIPTS)/exit_make.sh; fi'
############################################################################
# calls the script for preparing output directories and such.
pre_compilation:
- $(HIDESH)$(CLAM_DIR)/csharp/preconditions.sh
+ $(HIDESH)$(CLAM_SCRIPTS)/csharp/preconditions.sh
############################################################################
@@ -245,7 +245,7 @@ pre_compilation:
# we don't bother reporting errors from touch since there will sometimes
# not be any objects in the final directory.
post_compilation:
- $(HIDESH)$(CLAM_DIR)/csharp/postconditions.sh
+ $(HIDESH)$(CLAM_SCRIPTS)/csharp/postconditions.sh
############################################################################
diff --git a/scripts/clam/dotnet-retired/variables.def b/scripts/clam/dotnet-retired/variables.def
index d4ea88d8..a645b02f 100644
--- a/scripts/clam/dotnet-retired/variables.def
+++ b/scripts/clam/dotnet-retired/variables.def
@@ -9,7 +9,7 @@ include variables.def
###############################################################################
-#CLAM_BINARY_DIR = $(CLAM_DIR)/../bin
+#CLAM_BINARIES = $(CLAM_SCRIPTS)/../bin
###############################################################################
@@ -115,7 +115,7 @@ endif
# "OUTPUT_ROOT" is the root of all output directories for objects and other
# products being built.
-export OUTPUT_ROOT = $(TARGETS_DIR)/obj
+export OUTPUT_ROOT = $(TARGETS_STORE)/obj
# "PLATFORM_ADD_IN" is an option discriminator for the intended execution
# platform. it should end in an underscore if it is provided.
@@ -143,10 +143,10 @@ export OUTPUT_PATH = $(BASE_OUTPUT_PATH)/$(PROJECT)
export OBJECT_DIR = $(OUTPUT_PATH)
# These specify where files are to be created or located for our local build.
-export EXECUTABLE_DIR = $(TARGETS_DIR)/exe
-export DYNAMIC_LIBRARY_DIR = $(TARGETS_DIR)/dll
-export STATIC_LIBRARY_DIR = $(TARGETS_DIR)/lib
-export TESTS_DIR = $(TARGETS_DIR)/tests
+export EXECUTABLE_DIR = $(TARGETS_STORE)/exe
+export DYNAMIC_LIBRARY_DIR = $(TARGETS_STORE)/dll
+export STATIC_LIBRARY_DIR = $(TARGETS_STORE)/lib
+export TESTS_DIR = $(TARGETS_STORE)/tests
# "HEADER_SEARCH_PATH" is where the class interface files are to be found.
#HEADER_SEARCH_PATH =
@@ -312,7 +312,7 @@ LIBRARY_NAME_FLAG = -l
# the root name of the version file. This is currently irrelevant on
# non-win32 platforms.
-VERSION_RC_ROOT = $(shell $(SHELL) $(CLAM_DIR)/cpp/rc_name.sh)
+VERSION_RC_ROOT = $(shell $(SHELL) $(CLAM_SCRIPTS)/cpp/rc_name.sh)
# we import the rc_name from our close ally, the c++ compiler definitions.
###############################################################################
@@ -384,7 +384,7 @@ ifeq "$(COMPILER)" "VISUAL_CPP"
TLBEXPORT = $(COMPILER_ROOT_DIR)/../SDK/v$(SHORT_FRAMEWORK_VERSION)/bin/tlbexp$(EXE_END)
# calculate the visual studio root directory.
- export VIS_STU_ROOT := $(shell $(SHELL) $(CLAM_DIR)/cpp/ms_root_dir.sh $(CLAM_BINARY_DIR) )
+ export VIS_STU_ROOT := $(shell $(SHELL) $(CLAM_SCRIPTS)/cpp/ms_root_dir.sh $(CLAM_BINARIES) )
ifneq "$(VIS_STU_ROOT)" ""
COMPILER_ROOT_DIR = $(VIS_STU_ROOT)/vc#
endif
@@ -394,17 +394,17 @@ ifeq "$(COMPILER)" "VISUAL_CPP"
HOSEUP =
endif
- export COMPILER_VERSION = $(shell $(SHELL) $(CLAM_DIR)/cpp/get_version.sh $(COMPILER) $(COMPILER_ROOT_DIR) )
+ export COMPILER_VERSION = $(shell $(SHELL) $(CLAM_SCRIPTS)/cpp/get_version.sh $(COMPILER) $(COMPILER_ROOT_DIR) )
# set a variable for the resource compiler for old-style resources.
STANDARD_RC = $(VIS_STU_ROOT)/vc/bin/rc
# set up a directory for debugging files to be stored. these are not
# moved with the postconditions--they are generated in place.
- export PDB_DIR=$(TARGETS_DIR)/pdb
+ export PDB_DIR=$(TARGETS_STORE)/pdb
# set these way up here so we can override them later.
- CC = bash $(CLAM_DIR)/csharp/csharper.sh
+ CC = bash $(CLAM_SCRIPTS)/csharp/csharper.sh
##$(FRAMEWORK_DIR)/csc
# LINK_TOOL = $(COMPILER_ROOT_DIR)/bin/link
diff --git a/scripts/clam/make_subdirs.sh b/scripts/clam/make_subdirs.sh
index fcb8f8a8..a7fac78f 100755
--- a/scripts/clam/make_subdirs.sh
+++ b/scripts/clam/make_subdirs.sh
@@ -13,7 +13,7 @@ function make_subdirectories()
if [ -f "$burlap51/makefile" ]; then
#echo -e "\n\n[[inside barriers, with filename=$burlap51 and all conditions met]]\n\n"
pushd "$burlap51" &>/dev/null
- make --silent -I "$CLAM_DIR" NOT_FIRST_MAKE=t
+ make --silent -I "$CLAM_SCRIPTS" NOT_FIRST_MAKE=t
popd &>/dev/null
else
echo "(skipping directory $burlap51)"
diff --git a/scripts/clam/rules.def b/scripts/clam/rules.def
index 7258fc22..3cf8bf6e 100644
--- a/scripts/clam/rules.def
+++ b/scripts/clam/rules.def
@@ -24,13 +24,13 @@ endif
$(HIDER)echo
$(HIDER)echo [$@] is missing files or has a makefile problem.
$(HIDER)echo
- $(HIDESH)$(CLAM_DIR)/exit_make.sh
+ $(HIDESH)$(CLAM_SCRIPTS)/exit_make.sh
# This rule halts make for some supposedly devastating reason. More
# information should be printed out by the cause of the halt.
%.halt:
@echo CLAM execution halted, the cause being: $@
- $(HIDESH)$(CLAM_DIR)/exit_make.sh
+ $(HIDESH)$(CLAM_SCRIPTS)/exit_make.sh
# Provides a time-stamp in the make log.
show_date.%:
@@ -88,11 +88,11 @@ endif
# runs the programs specified in the RUN_TARGETS variable.
run_targets:
- $(HIDESH)"$(CLAM_DIR)/target_runner.sh"
+ $(HIDESH)"$(CLAM_SCRIPTS)/target_runner.sh"
# "make_subdirs" travels down each subdirectory and builds using make.
make_subdirs:
- $(HIDESH)$(CLAM_DIR)/make_subdirs.sh
+ $(HIDESH)$(CLAM_SCRIPTS)/make_subdirs.sh
# "clean" is a default target that removes object files, libs, executable
# files and such that were created by the project. it invokes the makefile
@@ -132,7 +132,7 @@ fi'
# "clean_subdirs" travels down each subdirectory and cleans using make.
clean_subdirs:
- $(HIDESH)$(CLAM_DIR)/clean_subdirs.sh
+ $(HIDESH)$(CLAM_SCRIPTS)/clean_subdirs.sh
# "rm_links" removes the files in the current directory that are links
# to other files. this is only useful in a unix environment.
diff --git a/scripts/clam/variables.def b/scripts/clam/variables.def
index d5e3181d..100fe6be 100644
--- a/scripts/clam/variables.def
+++ b/scripts/clam/variables.def
@@ -64,7 +64,7 @@ endif
# "FEISTY_MEOW_APEX" is the root of the "build" for our compilation oriented
# features. All source code and build helper files are usually found there.
# The build targets to be built are usually stored there also, although the
-# targets can be located elsewhere if desired. see TARGETS_DIR below.
+# targets can be located elsewhere if desired. see TARGETS_STORE below.
export FEISTY_MEOW_APEX
ifeq "$(FEISTY_MEOW_APEX)" ""
# FEISTY_MEOW_APEX =
@@ -79,30 +79,30 @@ ifeq "$(FEISTY_MEOW_SCRIPTS)" ""
export FEISTY_MEOW_SCRIPTS := $(FEISTY_MEOW_APEX)/scripts
endif
-# "PRODUCTION_DIR" is where components required for building the code or
+# "PRODUCTION_STORE" is where components required for building the code or
# installers can be found.
#hmmm: is this redundant?
-export PRODUCTION_DIR
-ifeq "$(PRODUCTION_DIR)" ""
- PRODUCTION_DIR=$(FEISTY_MEOW_APEX)/production
+export PRODUCTION_STORE
+ifeq "$(PRODUCTION_STORE)" ""
+ PRODUCTION_STORE=$(FEISTY_MEOW_APEX)/production
endif
-# "CLAM_DIR" points at where the CLAM source files are located. this is needed
+# "CLAM_SCRIPTS" points at where the CLAM source files are located. this is needed
# for finding shell scripts used during compilation. if you are not using the
# standard CLAM location, then modify this appropriately.
-export CLAM_DIR
-ifeq "$(CLAM_DIR)" ""
- export CLAM_DIR := $(FEISTY_MEOW_SCRIPTS)/clam
+export CLAM_SCRIPTS
+ifeq "$(CLAM_SCRIPTS)" ""
+ export CLAM_SCRIPTS := $(FEISTY_MEOW_SCRIPTS)/clam
endif
-# "TARGETS_DIR" is where all generated files will end up. Usually the
+# "TARGETS_STORE" is where all generated files will end up. Usually the
# files are put in a subdirectory named after their file type, such as
-# "include". These subdirectories will all live under the TARGETS_DIR.
-export TARGETS_DIR
-ifeq "$(TARGETS_DIR)" ""
+# "include". These subdirectories will all live under the TARGETS_STORE.
+export TARGETS_STORE
+ifeq "$(TARGETS_STORE)" ""
# the default is to generate files into subdirectories that are at the
# top-level of the repository.
- TARGETS_DIR = $(FEISTY_MEOW_APEX)
+ TARGETS_STORE = $(FEISTY_MEOW_APEX)
endif
# "CURRENT_DIR" is the directory where this make was started.
@@ -172,7 +172,7 @@ export FIND = find
# also contains any extra flags passed to the compilation.
ifeq "$(PARAMETER_FILE)" ""
# the default assumes that clam lives under the main hoople branch.
- export PARAMETER_FILE = $(CLAM_DIR)/clam_parms.ini
+ export PARAMETER_FILE = $(CLAM_SCRIPTS)/clam_parms.ini
endif
# ensure that our version variables are available to sub-shells.
@@ -198,7 +198,7 @@ export CLEAN
# sets the temporary directory.
export CLAM_TMP
ifeq "$(CLAM_TMP)" ""
- CLAM_TMP := $(GENERATED_DIR)/clam_tmp
+ CLAM_TMP := $(GENERATED_STORE)/clam_tmp
endif
#turned off for the moment, since this seems like a bad idea; we define clam tmp in terms of tmp sometimes, do not we???
@@ -259,7 +259,7 @@ HIDESH = $(HIDER) $(SH)
# "CATCHER" is a hider that looks for errors in the command being run and
# stops the make if any are seen.
-CATCHER = $(HIDESH) $(CLAM_DIR)/badness_catcher.sh
+CATCHER = $(HIDESH) $(CLAM_SCRIPTS)/badness_catcher.sh
# "NOISY" causes the compilation to be verbose. All commands issued are echoed
# to the standard output.
diff --git a/scripts/files/edit_files_matching.sh b/scripts/files/edit_files_matching.sh
new file mode 100644
index 00000000..98c57ed5
--- /dev/null
+++ b/scripts/files/edit_files_matching.sh
@@ -0,0 +1,59 @@
+#!/bin/bash
+
+# finds all files that contain any one of the members of a list of patterns.
+
+function print_instructions()
+{
+ echo "This script requires a directory as the first parameter and then a list of"
+ echo "patterns to find within that directory. All the files matching a pattern"
+ echo "in the list will be opened in an editor."
+
+ echo "for example:"
+
+ echo " $(basename $0 .sh) ~/feisty_meow hoople.net hoople.org"
+ echo "the above will search the directory ~/feisty_meow for all matches to"
+ echo "the two patterns 'hoople.org' and 'hoople.net'."
+
+ exit 1
+}
+
+# capture the first parameter for the directory and remove it.
+search_directory="$1"; shift
+
+if [ -z "$search_directory" -o -z "$2" -o ! -d "$search_directory" ]; then
+ print_instructions
+fi
+
+function launch_editor_on_matching_files()
+{
+ pushd "$search_directory"
+
+ local donk
+
+ # iterate over the rest of the parameters as patterns.
+ for donk in $*; do
+
+ echo "searching [$search_directory] for string [$donk]"
+ edit_list="$(bash $FEISTY_MEOW_SCRIPTS/text/search_text.sh $donk)"
+ if [ ! -z "$edit_list" ]; then
+ gvim $edit_list 2>&1 | cat
+ fi
+
+#np
+#hmmm: why doesn't the np alias work?
+
+ done
+
+ popd
+}
+
+# invoke our function to do the real work.
+launch_editor_on_matching_files $*
+
+##############
+
+# example run for scanning feisty meow code for old domain names that are
+# defunct:
+# edit_files_matching $FEISTY_MEOW_APEX hoople.net hoople.org hoople.com yeticode.org yeticode.com yeticode.net cromp.com cromp.org cromp.net gruntose.net gruntose.org koeritz.net
+
+
diff --git a/scripts/generator/build_variables.sh b/scripts/generator/build_variables.sh
index 2a30e2dc..e30bd079 100644
--- a/scripts/generator/build_variables.sh
+++ b/scripts/generator/build_variables.sh
@@ -56,20 +56,20 @@ if [ -z "$BUILD_VARS_LOADED" ]; then
# perform some calculations to get the right paths from our parameters.
if [ ! -z "$PARM_1" ]; then
# use the first real parameter since this is probably the 'source' version.
- export BUILD_SCRIPTS_DIR="$(dirname "$PARM_1")"
+ export BUILD_SCRIPTS_PATH="$(dirname "$PARM_1")"
THIS_TOOL_NAME="$(basename "$PARM_1")"
else
# use the zeroth parameter, since we know nothing more about our name.
- export BUILD_SCRIPTS_DIR="$(dirname "$PARM_0")"
+ export BUILD_SCRIPTS_PATH="$(dirname "$PARM_0")"
THIS_TOOL_NAME="$(basename "$PARM_0")"
fi
-BUILD_SCRIPTS_DIR="$(cd $(echo $BUILD_SCRIPTS_DIR | tr '\\\\' '/' ); \pwd)"
+BUILD_SCRIPTS_PATH="$(cd $(echo $BUILD_SCRIPTS_PATH | tr '\\\\' '/' ); \pwd)"
# figure out the other paths based on where we found this script.
-export BUILDING_HIERARCHY="$(echo "$BUILD_SCRIPTS_DIR" | sed -e 's/\(.*\)\/[^\/]*/\1/')"
-export CLAM_DIR="$(cd $BUILD_SCRIPTS_DIR/../clam ; \pwd)"
+export BUILDING_HIERARCHY="$(echo "$BUILD_SCRIPTS_PATH" | sed -e 's/\(.*\)\/[^\/]*/\1/')"
+export CLAM_SCRIPTS="$(cd $BUILD_SCRIPTS_PATH/../clam ; \pwd)"
# synonym to make other builds happy.
-export BUILDER_DIR="$BUILDING_HIERARCHY"
+export BUILDER_PATH="$BUILDING_HIERARCHY"
# set some clam parameters for compilation. if the script can't guess the
# right configuration, then you will need to set them in the last 'else'
@@ -99,30 +99,30 @@ export BUILD_TOP="$FEISTY_MEOW_APEX"
# the production directory is the location for all the scripts and setup
# code needed to produce the executables for feisty meow.
-export PRODUCTION_DIR="$BUILD_TOP/production"
+export PRODUCTION_STORE="$BUILD_TOP/production"
## set up the top-level for all build creations and logs and such.
-#export GENERATED_DIR="$TMP/generated-feisty_meow"
-#if [ ! -d "$GENERATED_DIR" ]; then
-# mkdir -p "$GENERATED_DIR"
+#export GENERATED_STORE="$TMP/generated-feisty_meow"
+#if [ ! -d "$GENERATED_STORE" ]; then
+# mkdir -p "$GENERATED_STORE"
#fi
## set up our effluent outsourcing valves.
-#export TEMPORARIES_DIR="$GENERATED_DIR/temporaries"
-#if [ ! -d "$TEMPORARIES_DIR" ]; then
-# mkdir -p "$TEMPORARIES_DIR"
+#export TEMPORARIES_PILE="$GENERATED_STORE/temporaries"
+#if [ ! -d "$TEMPORARIES_PILE" ]; then
+# mkdir -p "$TEMPORARIES_PILE"
#fi
# this variable points at a folder where we store the generated products of
# the build, such as the binaries and installer packages.
-export RUNTIME_DIR="$GENERATED_DIR/runtime"
-if [ ! -d "$RUNTIME_DIR" ]; then
- mkdir -p "$RUNTIME_DIR"
+export RUNTIME_PATH="$GENERATED_STORE/runtime"
+if [ ! -d "$RUNTIME_PATH" ]; then
+ mkdir -p "$RUNTIME_PATH"
fi
# we define a log file storage area that can be relied on by the build.
-export LOGS_DIR="$GENERATED_DIR/logs"
-if [ ! -d "$LOGS_DIR" ]; then
- mkdir -p "$LOGS_DIR"
+export FEISTY_MEOW_LOGS="$GENERATED_STORE/logs"
+if [ ! -d "$FEISTY_MEOW_LOGS" ]; then
+ mkdir -p "$FEISTY_MEOW_LOGS"
fi
##############
@@ -130,11 +130,11 @@ fi
# debugging area where we say what we think we know.
if [ ! -z "$SHELL_DEBUG" ]; then
- echo scripts: $BUILD_SCRIPTS_DIR
+ echo scripts: $BUILD_SCRIPTS_PATH
echo build tools hier: $BUILDING_HIERARCHY
echo this tool: $THIS_TOOL_NAME
echo repository: $FEISTY_MEOW_APEX
- echo clam: $CLAM_DIR
+ echo clam: $CLAM_SCRIPTS
fi
##############
@@ -146,16 +146,16 @@ pushd / &>/dev/null # jump to the root so relative paths are caught.
got_bad=
# first the scripts directory; do we find this script there?
-if [ ! -f "$BUILD_SCRIPTS_DIR/$THIS_TOOL_NAME" ]; then
+if [ ! -f "$BUILD_SCRIPTS_PATH/$THIS_TOOL_NAME" ]; then
echo "This script cannot locate the proper build folders. The crucial path"
- echo "variable seems to be '$BUILD_SCRIPTS_DIR', which"
+ echo "variable seems to be '$BUILD_SCRIPTS_PATH', which"
echo "does not seem to contain '$THIS_TOOL_NAME' (this"
echo "script's apparent name)."
got_bad=1
fi
# next the clam directory; is the main variables file present there?
-if [ -z "$got_bad" -a ! -f "$CLAM_DIR/variables.def" ]; then
+if [ -z "$got_bad" -a ! -f "$CLAM_SCRIPTS/variables.def" ]; then
echo "The clam directory could not be located under our build tools hierarchy."
echo "Please examine the configuration and make sure that this script is in a"
echo "directory that resides at the same height as the 'clam' directory."
@@ -178,17 +178,17 @@ fi
if [ -z "$got_bad" ]; then
# where we store the binaries used for building the rest of the code base.
- export CLAM_BINARY_DIR="$RUNTIME_DIR/clam_bin"
+ export CLAM_BINARIES="$RUNTIME_PATH/clam_bin"
# the final destination for the new binaries which provide the hoople
# build with all the apps it needs to get going.
- export TARGETS_DIR="$RUNTIME_DIR/binaries"
+ export TARGETS_STORE="$RUNTIME_PATH/binaries"
# targets directory is meaningful to clam, which will use it for output.
- export INTERMEDIATE_EXE_DIR="$TARGETS_DIR"
+ export INTERMEDIATE_STORE="$TARGETS_STORE"
# where we are building the apps before they get promoted.
#hmmm: could allow override on this if already set.
# calculate which build ini file to use.
- export BUILD_PARAMETER_FILE="$PRODUCTION_DIR/feisty_meow_config.ini"
+ export BUILD_PARAMETER_FILE="$PRODUCTION_STORE/feisty_meow_config.ini"
if [ ! -f "$BUILD_PARAMETER_FILE" ]; then
echo "Cannot find a useful build configuration file."
fi
@@ -202,13 +202,13 @@ if [ -z "$got_bad" ]; then
# we should have established our internal variables now, so let's try
# using them.
- export PATH=$(dos_to_unix_path $CLAM_BINARY_DIR):$PATH
+ export PATH=$(dos_to_unix_path $CLAM_BINARIES):$PATH
# load up the helper variables for visual studio on winders.
if [ "$OPERATING_SYSTEM" == "WIN32" ]; then
- source "$BUILD_SCRIPTS_DIR/vis_stu_vars.sh"
+ source "$BUILD_SCRIPTS_PATH/vis_stu_vars.sh"
else
- export LD_LIBRARY_PATH="$TARGETS_DIR"
+ export LD_LIBRARY_PATH="$TARGETS_STORE"
fi
popd &>/dev/null # checking is over, jump back to the starting point.
@@ -237,7 +237,7 @@ fi # outer wrapper for already ran build vars check.
# this always needs to be defined since functions aren't exported.
function make()
{
- /usr/bin/make -I "$CLAM_DIR" $*
+ /usr/bin/make -I "$CLAM_SCRIPTS" $*
}
diff --git a/scripts/generator/next_version.sh b/scripts/generator/next_version.sh
index 85b70e3a..61c5d410 100644
--- a/scripts/generator/next_version.sh
+++ b/scripts/generator/next_version.sh
@@ -2,7 +2,7 @@
# increments the build version number.
-mkdir -p "$TEMPORARIES_DIR"
+mkdir -p "$TEMPORARIES_PILE"
export PARAMETER_FILE
if [ ! -z "$BUILD_PARAMETER_FILE" ]; then
@@ -17,7 +17,7 @@ fi
chmod u+w "$PARAMETER_FILE"
-new_buildini="$(mktemp "$TEMPORARIES_DIR/buildini.XXXXXX")"
+new_buildini="$(mktemp "$TEMPORARIES_PILE/buildini.XXXXXX")"
# whack the file just in case.
rm -f "$new_buildini"
echo -n "" >"$new_buildini"
diff --git a/scripts/generator/whack_build.sh b/scripts/generator/whack_build.sh
index fb782772..9051c1a8 100644
--- a/scripts/generator/whack_build.sh
+++ b/scripts/generator/whack_build.sh
@@ -27,9 +27,9 @@ function whack_single_build_area()
# avoid accidentally removing important stuff if our variables have not been previously
# established.
- if [ -z "$GENERATED_DIR" -o -z "$TEMPORARIES_DIR" ]; then
- echo The build whacking script cannot run because either the GENERATED_DIR
- echo variable or the TEMPORARIES_DIR variable have not been set. This makes
+ if [ -z "$GENERATED_STORE" -o -z "$TEMPORARIES_PILE" ]; then
+ echo The build whacking script cannot run because either the GENERATED_STORE
+ echo variable or the TEMPORARIES_PILE variable have not been set. This makes
echo it unsafe to remove anything in the build products.
exit 1
fi
@@ -37,19 +37,19 @@ function whack_single_build_area()
# kerzap. the cleanups in production directory remove older locations of generated files.
rm -rf \
"$FEISTY_MEOW_APEX/generatedJUnitFiles" \
- "$GENERATED_DIR/clam_tmp" \
- "$GENERATED_DIR/logs" \
- "$PRODUCTION_DIR/__build_"*.h \
- "$PRODUCTION_DIR/manifest.txt" \
- "$RUNTIME_DIR/binaries" \
- "$RUNTIME_DIR/install" \
- "$RUNTIME_DIR/waste" \
- "$TEMPORARIES_DIR" \
- "$PRODUCTION_DIR/clam_bin" \
- "$PRODUCTION_DIR/binaries" \
- "$PRODUCTION_DIR/install" \
- "$PRODUCTION_DIR/logs" \
- "$PRODUCTION_DIR/waste"
+ "$GENERATED_STORE/clam_tmp" \
+ "$GENERATED_STORE/logs" \
+ "$PRODUCTION_STORE/__build_"*.h \
+ "$PRODUCTION_STORE/manifest.txt" \
+ "$RUNTIME_PATH/binaries" \
+ "$RUNTIME_PATH/install" \
+ "$RUNTIME_PATH/waste" \
+ "$TEMPORARIES_PILE" \
+ "$PRODUCTION_STORE/clam_bin" \
+ "$PRODUCTION_STORE/binaries" \
+ "$PRODUCTION_STORE/install" \
+ "$PRODUCTION_STORE/logs" \
+ "$PRODUCTION_STORE/waste"
# last few mentioning production dir are to clean older code.
# echo $(date): " cleaning generated files in source hierarchy..."
@@ -58,7 +58,7 @@ function whack_single_build_area()
echo $(date): " ** aggressive cleaning activated..."
# get rid of the build binaries.
- rm -rf "$CLAM_BINARY_DIR"
+ rm -rf "$CLAM_BINARIES"
perl "$FEISTY_MEOW_SCRIPTS/files/zapdirs.pl" "$FEISTY_MEOW_APEX" >>"$CRUDFILE"
fi
diff --git a/scripts/schedule/generate_reminders.pl b/scripts/schedule/generate_reminders.pl
index e48ff584..026aaba6 100644
--- a/scripts/schedule/generate_reminders.pl
+++ b/scripts/schedule/generate_reminders.pl
@@ -26,7 +26,7 @@
# The day must be a number, followed by a space. Anything after that
# space is considered the description of the event.
-use Env qw(CLOUD_DIR TMP);
+use Env qw(CLOUD_BASE TMP);
##############
@@ -43,7 +43,7 @@ local($CAL_FILE);
if (! $CAL_FILE) {
# print "the CAL_FILE variable is not set.\n";
# print "defaulting it to a value that probably does not suit you.\n";
- $CAL_FILE = "$CLOUD_DIR/infobase/lists/calendar.dat";
+ $CAL_FILE = "$CLOUD_BASE/infobase/lists/calendar.dat";
}
#print "calfile is $CAL_FILE\n";
diff --git a/scripts/shunit/example_shunit_test.sh b/scripts/shunit/example_shunit_test.sh
index ce84616c..17b3dd89 100644
--- a/scripts/shunit/example_shunit_test.sh
+++ b/scripts/shunit/example_shunit_test.sh
@@ -36,5 +36,5 @@ oneTimeTearDown()
}
# load and run shUnit2
-source $SHUNIT_DIR/shunit2
+source $SHUNIT_PATH/shunit2
diff --git a/scripts/users/group_spouter.sh b/scripts/users/group_spouter.sh
index e90df725..df0fb0a1 100644
--- a/scripts/users/group_spouter.sh
+++ b/scripts/users/group_spouter.sh
@@ -1,4 +1,4 @@
-sed -e 's/\([^:]*\):\([^:]*\):\([^:]*\):\([^:]*\):\([^:]*\):\([^:]*\):.*/sudo addgroup --gid \4 \1 ; sudo adduser \1 --uid \3 --gid \4/' < $CLOUD_DIR/configuration/users/fred_and_alts.passwd >$TMP/zz_spouted_groups.sh
+sed -e 's/\([^:]*\):\([^:]*\):\([^:]*\):\([^:]*\):\([^:]*\):\([^:]*\):.*/sudo addgroup --gid \4 \1 ; sudo adduser \1 --uid \3 --gid \4/' < $CLOUD_BASE/configuration/users/fred_and_alts.passwd >$TMP/zz_spouted_groups.sh
Now running the $TMP/spouted_groups.sh script to create the groups:
bash $TMP/zz_spouted_groups.sh
diff --git a/scripts/bookmarks/create_marks.sh b/scripts/bookmarks/create_marks.sh
index 359d3b12..ab9f2669 100644
--- a/scripts/bookmarks/create_marks.sh
+++ b/scripts/bookmarks/create_marks.sh
@@ -1,9 +1,9 @@
#!/bin/bash
# this script rebuilds the bookmarks files. it requires the variables:
-# WEB_DIR: points at the root of the web hierarchy.
+# WEBBED_SITES: points at the root of the web hierarchy.
-export GRUNTOSE_DIR=$WEB_DIR/gruntose.com
+export GRUNTOSE_DIR=$WEBBED_SITES/gruntose.com
rootname=$HOME/generated
suffix=.html
@@ -21,25 +21,25 @@ if [ -f $newmarx ]; then rm $newmarx; fi
if [ -f $genlinx_js ]; then rm $genlinx_js; fi
if [ -f $genlinx_moz ]; then rm $genlinx_moz; fi
-$RUNTIME_DIR/binaries/marks_sorter -i $GRUNTOSE_DIR/Info/Twain/links_db.csv -o $newmarx
+$RUNTIME_PATH/binaries/marks_sorter -i $GRUNTOSE_DIR/Info/Twain/links_db.csv -o $newmarx
if [ $? != 0 ]; then
echo error during sorting of the bookmarks.
exit 1
fi
-$RUNTIME_DIR/binaries/marks_maker -i $GRUNTOSE_DIR/Info/Twain/links_db.csv -t $GRUNTOSE_DIR/Info/Twain/marks_template.html -o $genlinx -s human
+$RUNTIME_PATH/binaries/marks_maker -i $GRUNTOSE_DIR/Info/Twain/links_db.csv -t $GRUNTOSE_DIR/Info/Twain/marks_template.html -o $genlinx -s human
if [ $? != 0 ]; then
echo error during creation of the normal web page of bookmarks.
exit 1
fi
-$RUNTIME_DIR/binaries/marks_maker -i $GRUNTOSE_DIR/Info/Twain/links_db.csv -t $GRUNTOSE_DIR/Info/Twain/marks_template.html -o $genlinx_moz -s mozilla
+$RUNTIME_PATH/binaries/marks_maker -i $GRUNTOSE_DIR/Info/Twain/links_db.csv -t $GRUNTOSE_DIR/Info/Twain/marks_template.html -o $genlinx_moz -s mozilla
if [ $? != 0 ]; then
echo error during creation of the mozilla format page of bookmarks.
exit 1
fi
-$RUNTIME_DIR/binaries/js_marks_maker -i $GRUNTOSE_DIR/Info/Twain/links_db.csv -t $GRUNTOSE_DIR/Info/Twain/js_template.html -o $genlinx_js
+$RUNTIME_PATH/binaries/js_marks_maker -i $GRUNTOSE_DIR/Info/Twain/links_db.csv -t $GRUNTOSE_DIR/Info/Twain/js_template.html -o $genlinx_js
if [ $? != 0 ]; then
echo error during creation of the javascript bookmark page.
exit 1
diff --git a/scripts/core/variables.sh b/scripts/core/variables.sh
index 1ec14e31..233fadb3 100644
--- a/scripts/core/variables.sh
+++ b/scripts/core/variables.sh
@@ -106,18 +106,18 @@ if [ -z "$CORE_VARIABLES_LOADED" ]; then
fi
# set up the top-level for all build creations and logs and such.
- if [ -z "$GENERATED_DIR" ]; then
- define_yeti_variable GENERATED_DIR="$TMP/generated-feisty_meow"
+ if [ -z "$GENERATED_STORE" ]; then
+ define_yeti_variable GENERATED_STORE="$TMP/generated-feisty_meow"
fi
- if [ ! -d "$GENERATED_DIR" ]; then
- mkdir -p "$GENERATED_DIR"
+ if [ ! -d "$GENERATED_STORE" ]; then
+ mkdir -p "$GENERATED_STORE"
fi
# set up our effluent outsourcing valves.
- if [ -z "$TEMPORARIES_DIR" ]; then
- define_yeti_variable TEMPORARIES_DIR="$GENERATED_DIR/temporaries"
+ if [ -z "$TEMPORARIES_PILE" ]; then
+ define_yeti_variable TEMPORARIES_PILE="$GENERATED_STORE/temporaries"
fi
- if [ ! -d "$TEMPORARIES_DIR" ]; then
- mkdir -p "$TEMPORARIES_DIR"
+ if [ ! -d "$TEMPORARIES_PILE" ]; then
+ mkdir -p "$TEMPORARIES_PILE"
fi
# similarly, make sure we have someplace to look for our generated files, if
@@ -212,7 +212,7 @@ if [ -z "$CORE_VARIABLES_LOADED" ]; then
# now augment the environment if we found our build variables.
if [ $found_build_vars == 1 ]; then
# the binary directory contains our collection of handy programs.
- define_yeti_variable FEISTY_MEOW_BINARIES=$TARGETS_DIR
+ define_yeti_variable FEISTY_MEOW_BINARIES=$TARGETS_STORE
# add binaries created within build to the path.
define_yeti_variable PATH="$(dos_to_unix_path $FEISTY_MEOW_BINARIES):$PATH"
# Shared libraries are located via this variable.
@@ -241,8 +241,8 @@ if [ -z "$CORE_VARIABLES_LOADED" ]; then
##############
- # set the SHUNIT_DIR so our shunit tests can find the codebase.
- define_yeti_variable SHUNIT_DIR="$FEISTY_MEOW_SCRIPTS/shunit"
+ # set the SHUNIT_PATH so our shunit tests can find the codebase.
+ define_yeti_variable SHUNIT_PATH="$FEISTY_MEOW_SCRIPTS/shunit"
##############
diff --git a/scripts/generator/produce_feisty_meow.sh b/scripts/generator/produce_feisty_meow.sh
index cd5ed651..dcac3652 100644
--- a/scripts/generator/produce_feisty_meow.sh
+++ b/scripts/generator/produce_feisty_meow.sh
@@ -30,15 +30,15 @@ export PATH=/bin:$PATH
export INCLUDED_FROM_BOOTSTRAP=true
# pull in our build variables using the path to this script.
-export BUILD_SCRIPTS_DIR="$( \cd "$(\dirname "$0")" && /bin/pwd )"
-#echo build scripts dir initial value: $BUILD_SCRIPTS_DIR
-BUILD_SCRIPTS_DIR="$(echo $BUILD_SCRIPTS_DIR | tr '\\\\' '/' )"
-#echo build scripts dir after chewing: $BUILD_SCRIPTS_DIR
+export BUILD_SCRIPTS_PATH="$( \cd "$(\dirname "$0")" && /bin/pwd )"
+#echo build scripts dir initial value: $BUILD_SCRIPTS_PATH
+BUILD_SCRIPTS_PATH="$(echo $BUILD_SCRIPTS_PATH | tr '\\\\' '/' )"
+#echo build scripts dir after chewing: $BUILD_SCRIPTS_PATH
# load in feisty meow basic scripts, if not already loaded.
if [ -z "$FEISTY_MEOW_SCRIPTS_LOADED" ]; then
- bash "$BUILD_SCRIPTS_DIR/../core/reconfigure_feisty_meow.sh"
- source "$BUILD_SCRIPTS_DIR/../core/launch_feisty_meow.sh"
+ bash "$BUILD_SCRIPTS_PATH/../core/reconfigure_feisty_meow.sh"
+ source "$BUILD_SCRIPTS_PATH/../core/launch_feisty_meow.sh"
fi
source "$FEISTY_MEOW_SCRIPTS/core/functions.sh"
@@ -48,7 +48,7 @@ source "$FEISTY_MEOW_SCRIPTS/core/functions.sh"
export FEISTY_MEOW_APEX="$(unix_to_dos_path $FEISTY_MEOW_APEX)"
# load in build variables based on our deduced paths.
-source "$BUILD_SCRIPTS_DIR/build_variables.sh" "$BUILD_SCRIPTS_DIR/build_variables.sh"
+source "$BUILD_SCRIPTS_PATH/build_variables.sh" "$BUILD_SCRIPTS_PATH/build_variables.sh"
##############
@@ -56,13 +56,13 @@ source "$BUILD_SCRIPTS_DIR/build_variables.sh" "$BUILD_SCRIPTS_DIR/build_variabl
function prepare_binaries_dir()
{
# we'll store binaries here from the bootstrap process.
- if [ ! -d "$CLAM_BINARY_DIR" ]; then
- echo "creating binary dir now in $CLAM_BINARY_DIR"
- mkdir -p "$CLAM_BINARY_DIR"
+ if [ ! -d "$CLAM_BINARIES" ]; then
+ echo "creating binary dir now in $CLAM_BINARIES"
+ mkdir -p "$CLAM_BINARIES"
fi
- if [ ! -f "$CLAM_BINARY_DIR/paths.ini" ]; then
+ if [ ! -f "$CLAM_BINARIES/paths.ini" ]; then
echo "copied paths.ini to binary dir."
- cp "$PRODUCTION_DIR/paths.ini" "$CLAM_BINARY_DIR"
+ cp "$PRODUCTION_STORE/paths.ini" "$CLAM_BINARIES"
fi
}
@@ -112,10 +112,10 @@ function make_code {
function strip_cr {
ctrl_m=$'\015'
for i in $*; do
- tempgrep="$(mktemp "$TEMPORARIES_DIR/tempgrep.XXXXXX")"
+ tempgrep="$(mktemp "$TEMPORARIES_PILE/tempgrep.XXXXXX")"
grep -l "$ctrl_m" "$i" >$tempgrep
if [ ! -z "$(cat $tempgrep)" ]; then
- temp="$(mktemp "$TEMPORARIES_DIR/tempsed.XXXXXX")"
+ temp="$(mktemp "$TEMPORARIES_PILE/tempsed.XXXXXX")"
sed -e "s/$ctrl_m$//" <$i >$temp
mv -f $temp $i
fi
@@ -132,24 +132,24 @@ if [ "$OPERATING_SYSTEM" = "UNIX" ]; then
function promote {
prepare_binaries_dir
- if [ ! -f "$INTERMEDIATE_EXE_DIR/$1" ]; then
+ if [ ! -f "$INTERMEDIATE_STORE/$1" ]; then
echo "Failed to build the application $1--quitting now."
exit 1892
fi
- cp "$INTERMEDIATE_EXE_DIR/$1" "$CLAM_BINARY_DIR/$1"
- strip "$CLAM_BINARY_DIR/$1"
- chmod 755 "$CLAM_BINARY_DIR/$1"
+ cp "$INTERMEDIATE_STORE/$1" "$CLAM_BINARIES/$1"
+ strip "$CLAM_BINARIES/$1"
+ chmod 755 "$CLAM_BINARIES/$1"
}
elif [ "$OPERATING_SYSTEM" = "WIN32" ]; then
function promote {
prepare_binaries_dir
- if [ ! -f "$INTERMEDIATE_EXE_DIR/$1.exe" ]; then
+ if [ ! -f "$INTERMEDIATE_STORE/$1.exe" ]; then
echo "Failed to build the application $1.exe--quitting now."
exit 1892
fi
- cp "$INTERMEDIATE_EXE_DIR/$1.exe" "$CLAM_BINARY_DIR"
- chmod 755 "$CLAM_BINARY_DIR/$1.exe"
+ cp "$INTERMEDIATE_STORE/$1.exe" "$CLAM_BINARIES"
+ chmod 755 "$CLAM_BINARIES/$1.exe"
}
else
echo "The OPERATING_SYSTEM variable is unset or unknown. Bailing out."
@@ -161,37 +161,37 @@ fi
# start the actual build process now...
# load in the feisty meow building environment.
-source "$BUILD_SCRIPTS_DIR/build_variables.sh" "$BUILD_SCRIPTS_DIR/build_variables.sh"
+source "$BUILD_SCRIPTS_PATH/build_variables.sh" "$BUILD_SCRIPTS_PATH/build_variables.sh"
# clean out any current contents.
-bash "$BUILD_SCRIPTS_DIR/whack_build.sh" clean
+bash "$BUILD_SCRIPTS_PATH/whack_build.sh" clean
# make this again so no one gets cranky.
-mkdir -p "$LOGS_DIR"
+mkdir -p "$FEISTY_MEOW_LOGS"
toolset_names=(makedep value_tagger version_stamper vsts_version_fixer write_build_config short_path sleep_ms zap_process playsound create_guid)
if [ -z "$SAVE_BINARIES" ]; then
for i in ${toolset_names[*]}; do
- whack_name="$CLAM_BINARY_DIR/$i$EXE_ENDING"
+ whack_name="$CLAM_BINARIES/$i$EXE_ENDING"
#echo removing "$whack_name"
rm -f "$whack_name"
done
fi
# make the clam shell scripts executable.
-chmod 755 "$CLAM_DIR"/*.sh
-chmod 755 "$CLAM_DIR"/cpp/*.sh
-#chmod 755 "$CLAM_DIR"/csharp/*.sh
+chmod 755 "$CLAM_SCRIPTS"/*.sh
+chmod 755 "$CLAM_SCRIPTS"/cpp/*.sh
+#chmod 755 "$CLAM_SCRIPTS"/csharp/*.sh
chmod 755 "$FEISTY_MEOW_SCRIPTS/generator/wrapdoze.sh"
# rebuild the dependency tool. needed by everything, pretty much, but
# since it's from the xfree project, it doesn't need any of our libraries.
-if [ ! -f "$CLAM_BINARY_DIR/makedep$EXE_ENDING" ]; then
+if [ ! -f "$CLAM_BINARIES/makedep$EXE_ENDING" ]; then
pushd "$TOOL_SOURCES/dependency_tool" &>/dev/null
make_code pre_compilation NO_DEPS=t OMIT_VERSIONS=t
make_code NO_DEPS=t OMIT_VERSIONS=t
- if [ ! -f "$INTERMEDIATE_EXE_DIR/makedep$EXE_ENDING" ]; then
+ if [ ! -f "$INTERMEDIATE_STORE/makedep$EXE_ENDING" ]; then
echo ""
echo ""
echo "The build of the makedep tool has failed. Unknown causes... Argh."
@@ -204,17 +204,17 @@ if [ ! -f "$CLAM_BINARY_DIR/makedep$EXE_ENDING" ]; then
fi
# rebuild the version tools and other support apps.
-if [ ! -f "$CLAM_BINARY_DIR/value_tagger$EXE_ENDING" \
- -o ! -f "$CLAM_BINARY_DIR/version_stamper$EXE_ENDING" \
- -o ! -f "$CLAM_BINARY_DIR/vsts_version_fixer$EXE_ENDING" \
- -o ! -f "$CLAM_BINARY_DIR/write_build_config$EXE_ENDING" ]; then
+if [ ! -f "$CLAM_BINARIES/value_tagger$EXE_ENDING" \
+ -o ! -f "$CLAM_BINARIES/version_stamper$EXE_ENDING" \
+ -o ! -f "$CLAM_BINARIES/vsts_version_fixer$EXE_ENDING" \
+ -o ! -f "$CLAM_BINARIES/write_build_config$EXE_ENDING" ]; then
pushd "$TOOL_SOURCES/clam_tools" &>/dev/null
make_code pre_compilation OMIT_VERSIONS=t
make_code OMIT_VERSIONS=t
#hmmm: really this should check all the expected apps.
# nice to just have an array of the things built by this guy.
- if [ ! -f "$INTERMEDIATE_EXE_DIR/version_stamper$EXE_ENDING" ]; then
+ if [ ! -f "$INTERMEDIATE_STORE/version_stamper$EXE_ENDING" ]; then
echo ""
echo ""
echo "The build of the version_stamper tool has failed. Unknown causes... Argh."
@@ -231,11 +231,11 @@ if [ ! -f "$CLAM_BINARY_DIR/value_tagger$EXE_ENDING" \
fi
# build a few other utilities.
-if [ ! -f "$CLAM_BINARY_DIR/short_path$EXE_ENDING" \
- -o ! -f "$CLAM_BINARY_DIR/sleep_ms$EXE_ENDING" \
- -o ! -f "$CLAM_BINARY_DIR/create_guid$EXE_ENDING" \
- -o ! -f "$CLAM_BINARY_DIR/zap_process$EXE_ENDING" \
- -o ! -f "$CLAM_BINARY_DIR/playsound$EXE_ENDING" ]; then
+if [ ! -f "$CLAM_BINARIES/short_path$EXE_ENDING" \
+ -o ! -f "$CLAM_BINARIES/sleep_ms$EXE_ENDING" \
+ -o ! -f "$CLAM_BINARIES/create_guid$EXE_ENDING" \
+ -o ! -f "$CLAM_BINARIES/zap_process$EXE_ENDING" \
+ -o ! -f "$CLAM_BINARIES/playsound$EXE_ENDING" ]; then
pushd "$TOOL_SOURCES/simple_utilities" &>/dev/null
make_code pre_compilation OMIT_VERSIONS=t
make_code OMIT_VERSIONS=t
@@ -254,13 +254,13 @@ echo "The build binaries have been re-created (or were already present)."
# we won't do the full build if they told us to just do the bootstrap.
if [ -z "$JUST_BOOTSTRAP_APPS" ]; then
echo Cleaning up the temporary files that were built.
- bash "$BUILD_SCRIPTS_DIR/whack_build.sh"
+ bash "$BUILD_SCRIPTS_PATH/whack_build.sh"
#wrong! we don't want to whack it all. clean
# recreate our useful junk directories...
- mkdir -p "$GENERATED_DIR"
- mkdir -p "$TEMPORARIES_DIR"
- mkdir -p "$LOGS_DIR"
+ mkdir -p "$GENERATED_STORE"
+ mkdir -p "$TEMPORARIES_PILE"
+ mkdir -p "$FEISTY_MEOW_LOGS"
echo Now starting a normal build of the repository source code.
pushd "$FEISTY_MEOW_APEX" &>/dev/null